@@ -17,28 +17,25 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
-
 #ifndef LAYER_INFO_DIALOG_HPP
 #define LAYER_INFO_DIALOG_HPP
 
 #include "ui_layer_info.h"
 #include <QDialog>
 
-namespace mapnik
-{
+namespace mapnik {
 class layer;
 }
 
 class layer_info_dialog : public QDialog
 {
-  Q_OBJECT
+    Q_OBJECT
   public:
-    layer_info_dialog(mapnik::layer& l, QWidget * parent = 0);
+    layer_info_dialog(mapnik::layer& l, QWidget* parent = 0);
     Ui::LayerInfoDialog& getUI();
-   private:
-      Ui::LayerInfoDialog ui;
+
+  private:
+    Ui::LayerInfoDialog ui;
 };
 
-
-#endif //LAYER_INFO_DIALOG_HPP
+#endif // LAYER_INFO_DIALOG_HPP
