@@ -33,12 +33,10 @@ class LayerDelegate : public QAbstractItemDelegate
 {
     Q_OBJECT
 
-public:
-    LayerDelegate(QObject *parent = 0);
-    void paint(QPainter *painter, const QStyleOptionViewItem &option,
-    const QModelIndex &index) const;
-    QSize sizeHint(const QStyleOptionViewItem &option,
-                       const QModelIndex &index ) const;
+  public:
+    LayerDelegate(QObject* parent = 0);
+    void paint(QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
+    QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
 };
 
-#endif //LAYER_DELEGATE_HPP
+#endif // LAYER_DELEGATE_HPP
