@@ -17,27 +17,26 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  */
 
-
-
 #include "layerlistmodel.hpp"
 #include <QIcon>
-
-#include <iostream>
+#include <QBrush>
 #include <mapnik/layer.hpp>
 
 using mapnik::Map;
 
-LayerListModel::LayerListModel(std::shared_ptr<Map> map,QObject *parent)
-    : QAbstractListModel(parent),
-      map_(map) {}
+LayerListModel::LayerListModel(std::shared_ptr<Map> map, QObject* parent)
+    : QAbstractListModel(parent)
+    , map_(map)
+{}
 
 int LayerListModel::rowCount(QModelIndex const&) const
 {
-   if (map_) return map_->layers().size();
-   return 0;
+    if (map_)
+        return map_->layers().size();
+    return 0;
 }
 
-QVariant LayerListModel::data(QModelIndex const& index,int role) const
+QVariant LayerListModel::data(QModelIndex const& index, int role) const
 {
     if (!index.isValid() || !map_)
         return QVariant();
@@ -60,9 +59,16 @@ QVariant LayerListModel::data(QModelIndex const& index,int role) const
     else if (role == Qt::CheckStateRole)
     {
         if (map_->layers().at(index.row()).active())
-           return QVariant(Qt::Checked);
+            return QVariant(Qt::Checked);
         else
-           return QVariant(Qt::Unchecked);
+            return QVariant(Qt::Unchecked);
+    }
+    else if (role == Qt::ForegroundRole)
+    {
+        if (map_->layers().at(index.row()).active())
+            return QBrush(QColor("black"));
+        else
+            return QBrush(QColor("lightgrey"));
     }
     else
     {
@@ -70,8 +76,7 @@ QVariant LayerListModel::data(QModelIndex const& index,int role) const
     }
 }
 
-QVariant LayerListModel::headerData(int section, Qt::Orientation orientation,
-                                         int role) const
+QVariant LayerListModel::headerData(int section, Qt::Orientation orientation, int role) const
 {
     if (role != Qt::DisplayRole)
         return QVariant();
@@ -82,38 +87,37 @@ QVariant LayerListModel::headerData(int section, Qt::Orientation orientation,
         return QString("TODO Row %1").arg(section);
 }
 
-bool LayerListModel::setData(const QModelIndex &index,
-                             const QVariant &value, int role)
+bool LayerListModel::setData(const QModelIndex& index, const QVariant& value, int role)
 {
-   if (!map_) return false;
+    if (!map_)
+        return false;
 
-   if (index.isValid() && role == Qt::CheckStateRole)
-   {
-      int status = value.toInt();
-      std::vector<mapnik::layer> & layers = const_cast<std::vector<mapnik::layer>& >(map_->layers());
-      layers.at(index.row()).set_active(status);
-      emit dataChanged(index, index);
-      return true;
-   }
-   return false;
+    if (index.isValid() && role == Qt::CheckStateRole)
+    {
+        int status = value.toInt();
+        std::vector<mapnik::layer>& layers = const_cast<std::vector<mapnik::layer>&>(map_->layers());
+        layers.at(index.row()).set_active(status);
+        emit dataChanged(index, index);
+        return true;
+    }
+    return false;
 }
 
 Qt::ItemFlags LayerListModel::flags(QModelIndex const& index) const
 {
     Qt::ItemFlags flags = QAbstractItemModel::flags(index);
-
     if (index.isValid())
-       flags |= Qt::ItemIsUserCheckable;
+        flags |= Qt::ItemIsUserCheckable;
     return flags;
 }
 
 boost::optional<mapnik::layer&> LayerListModel::map_layer(int i)
 {
-   if (map_)
-   {
-      std::vector<mapnik::layer> & layers = const_cast<std::vector<mapnik::layer>& >(map_->layers());
-      if (i < int(layers.size()))
-          return boost::optional<mapnik::layer&>(layers[i]);
-   }
-   return boost::optional<mapnik::layer&>();
+    if (map_)
+    {
+        std::vector<mapnik::layer>& layers = const_cast<std::vector<mapnik::layer>&>(map_->layers());
+        if (i < int(layers.size()))
+            return boost::optional<mapnik::layer&>(layers[i]);
+    }
+    return boost::optional<mapnik::layer&>();
 }
