@@ -37,13 +37,9 @@ namespace mapnik {
 struct rasterizer;
 struct marker_svg;
 
-template <typename T>
-void render_pattern(marker_svg const& marker,
-                    agg::trans_affine const& tr,
-                    double opacity,
-                    T & image);
+template<typename T>
+void render_pattern(marker_svg const& marker, agg::trans_affine const& tr, double opacity, T& image);
 
 } // namespace mapnik
 
-
 #endif // MAPNIK_RENDER_PATTERN_HPP
