@@ -23,9 +23,9 @@
 #ifndef MAPNIK_XML_ATTRIBUTE_CAST_HPP
 #define MAPNIK_XML_ATTRIBUTE_CAST_HPP
 
-//mapnik
+// mapnik
 #include <mapnik/debug.hpp>
-#include <mapnik/value_types.hpp>
+#include <mapnik/value/types.hpp>
 #include <mapnik/xml_tree.hpp>
 #include <mapnik/enumeration.hpp>
 #include <mapnik/boolean.hpp>
@@ -36,24 +36,21 @@
 #include <mapnik/attribute.hpp>
 #include <mapnik/text/font_feature_settings.hpp>
 
-#pragma GCC diagnostic push
-#include <mapnik/warning_ignore.hpp>
-#include <boost/optional.hpp>
-#pragma GCC diagnostic pop
-
 // stl
 #include <string>
 #include <map>
 #include <typeinfo>
 #include <utility>
+#include <optional>
 #include <stdexcept>
 
-namespace mapnik { namespace detail {
+namespace mapnik {
+namespace detail {
 
-template <typename T>
+template<typename T>
 struct do_xml_attribute_cast
 {
-    static inline boost::optional<T> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& /*source*/)
+    static inline std::optional<T> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& /*source*/)
     {
         std::string err_msg("No conversion from std::string to ");
         err_msg += std::string(typeid(T).name());
@@ -62,55 +59,58 @@ struct do_xml_attribute_cast
 };
 
 // specialization for mapnik::boolean_type
-template <>
+template<>
 struct do_xml_attribute_cast<mapnik::boolean_type>
 {
-    static inline boost::optional<mapnik::boolean_type> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<mapnik::boolean_type> xml_attribute_cast_impl(xml_tree const& /*tree*/,
+                                                                              std::string const& source)
     {
         bool result;
         if (mapnik::util::string2bool(source, result))
-            return boost::optional<mapnik::boolean_type>(result);
-        return boost::optional<mapnik::boolean_type>();
+            return result;
+        return std::nullopt;
     }
 };
 
 // specialization for mapnik::value_bool
-template <>
+template<>
 struct do_xml_attribute_cast<mapnik::value_bool>
 {
-    static inline boost::optional<mapnik::value_bool> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<mapnik::value_bool> xml_attribute_cast_impl(xml_tree const& /*tree*/,
+                                                                            std::string const& source)
     {
         bool result;
         if (mapnik::util::string2bool(source, result))
-            return boost::optional<mapnik::value_bool>(result);
-        return boost::optional<mapnik::value_bool>();
+            return result;
+        return std::nullopt;
     }
 };
 
 // specialization for int
-template <>
+template<>
 struct do_xml_attribute_cast<int>
 {
-    static inline boost::optional<int> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<int> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
     {
         int result;
         if (mapnik::util::string2int(source, result))
-            return boost::optional<int>(result);
-        return boost::optional<int>();
+            return result;
+        return std::nullopt;
     }
 };
 
 #ifdef BIGINT
 // specialization for long long
-template <>
+template<>
 struct do_xml_attribute_cast<mapnik::value_integer>
 {
-    static inline boost::optional<mapnik::value_integer> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<mapnik::value_integer> xml_attribute_cast_impl(xml_tree const& /*tree*/,
+                                                                               std::string const& source)
     {
         int result;
         if (mapnik::util::string2int(source, result))
-            return boost::optional<mapnik::value_integer>(result);
-        return boost::optional<mapnik::value_integer>();
+            return result;
+        return std::nullopt;
     }
 };
 
@@ -118,92 +118,97 @@ struct do_xml_attribute_cast<mapnik::value_integer>
 
 // specialization for unsigned
 
-template <>
+template<>
 struct do_xml_attribute_cast<unsigned>
 {
-    static inline boost::optional<unsigned> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<unsigned> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
     {
         int result;
         if (mapnik::util::string2int(source, result) && result >= 0)
-            return boost::optional<unsigned>(static_cast<unsigned>(result));
-        return boost::optional<unsigned>();
+            return static_cast<unsigned>(result);
+        return std::nullopt;
     }
 };
 
 // specialization for float
-template <>
+template<>
 struct do_xml_attribute_cast<float>
 {
-    static inline boost::optional<float> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<float> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
     {
         float result;
         if (mapnik::util::string2float(source, result))
-            return boost::optional<float>(result);
-        return boost::optional<float>();
+            return result;
+        return std::nullopt;
     }
 };
 
 // specialization for double
-template <>
+template<>
 struct do_xml_attribute_cast<double>
 {
-    static inline boost::optional<double> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    static inline std::optional<double> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
     {
         double result;
         if (mapnik::util::string2double(source, result))
-            return boost::optional<double>(result);
-        return boost::optional<double>();
+            return result;
+        return std::nullopt;
     }
 };
 
-// specialization for mapnik::enumeration<T,int>
-template <typename T, int MAX>
-struct do_xml_attribute_cast<mapnik::enumeration<T,MAX> >
+// specialization for mapnik::enumeration<...>
+template<typename ENUM,
+         char const* (*F_TO_STRING)(ENUM),
+         ENUM (*F_FROM_STRING)(const char*),
+         std::map<ENUM, std::string> (*F_LOOKUP)()>
+struct do_xml_attribute_cast<mapnik::enumeration<ENUM, F_TO_STRING, F_FROM_STRING, F_LOOKUP>>
 {
-    static inline boost::optional<mapnik::enumeration<T,MAX> > xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
+    using Enum = mapnik::enumeration<ENUM, F_TO_STRING, F_FROM_STRING, F_LOOKUP>;
+    static inline std::optional<Enum> xml_attribute_cast_impl(xml_tree const& /*tree*/, std::string const& source)
     {
-        using result_type = typename boost::optional<mapnik::enumeration<T,MAX> >;
         try
         {
-            mapnik::enumeration<T,MAX> e;
+            Enum e;
             e.from_string(source);
-            return result_type(e);
+            return e;
         }
         catch (illegal_enum_value const& ex)
         {
             MAPNIK_LOG_ERROR(do_xml_attribute_cast) << ex.what();
-            return result_type();
+            return std::nullopt;
+            ;
         }
     }
 };
 
 // specialization for mapnik::color
-template <>
+template<>
 struct do_xml_attribute_cast<mapnik::color>
 {
-    static inline boost::optional<mapnik::color> xml_attribute_cast_impl(xml_tree const&, std::string const& source)
+    static inline std::optional<mapnik::color> xml_attribute_cast_impl(xml_tree const&, std::string const& source)
     {
         return parse_color(source);
     }
 };
 
 // specialization for std::string
-template <>
+template<>
 struct do_xml_attribute_cast<std::string>
 {
-    static inline boost::optional<std::string> xml_attribute_cast_impl(xml_tree const&, std::string const& source)
+    static inline std::optional<std::string> xml_attribute_cast_impl(xml_tree const&, std::string const& source)
     {
-        return boost::optional<std::string>(source);
+        return source;
     }
 };
 
 // specialization for mapnik::expression_ptr
-template <>
+template<>
 struct do_xml_attribute_cast<mapnik::expression_ptr>
 {
-    static inline boost::optional<mapnik::expression_ptr> xml_attribute_cast_impl(xml_tree const& tree, std::string const& source)
+    static inline std::optional<mapnik::expression_ptr> xml_attribute_cast_impl(xml_tree const& tree,
+                                                                                std::string const& source)
     {
-        std::map<std::string,mapnik::expression_ptr>::const_iterator itr = tree.expr_cache_.find(source);
+        std::map<std::string, mapnik::expression_ptr>::const_iterator itr = tree.expr_cache_.find(source);
         if (itr != tree.expr_cache_.end())
         {
             return itr->second;
@@ -211,17 +216,18 @@ struct do_xml_attribute_cast<mapnik::expression_ptr>
         else
         {
             mapnik::expression_ptr expr = parse_expression(source);
-            tree.expr_cache_.emplace(source,expr);
+            tree.expr_cache_.emplace(source, expr);
             return expr;
         }
     }
 };
 
 // specialization for mapnik::font_feature_settings
-template <>
+template<>
 struct do_xml_attribute_cast<mapnik::font_feature_settings>
 {
-    static inline boost::optional<mapnik::font_feature_settings> xml_attribute_cast_impl(xml_tree const&, std::string const& source)
+    static inline std::optional<mapnik::font_feature_settings> xml_attribute_cast_impl(xml_tree const&,
+                                                                                       std::string const& source)
     {
         return mapnik::font_feature_settings(source);
     }
@@ -229,8 +235,8 @@ struct do_xml_attribute_cast<mapnik::font_feature_settings>
 
 } // end namespace detail
 
-template <typename T>
-boost::optional<T> xml_attribute_cast(xml_tree const& tree, std::string const& source)
+template<typename T>
+std::optional<T> xml_attribute_cast(xml_tree const& tree, std::string const& source)
 {
     return detail::do_xml_attribute_cast<T>::xml_attribute_cast_impl(tree, source);
 }
