@@ -38,21 +38,22 @@
 #include <mapnik/boolean.hpp>
 #include <mapnik/util/trim.hpp>
 #include <mapnik/geometry.hpp>
-#include <mapnik/geometry_adapters.hpp>
+#include <mapnik/geometry/boost_adapters.hpp>
 #include <mapnik/util/geometry_to_ds_type.hpp>
-#include <mapnik/value_types.hpp>
+#include <mapnik/value/types.hpp>
 #include <mapnik/util/fs.hpp>
-#include <mapnik/make_unique.hpp>
 #include <mapnik/util/spatial_index.hpp>
 #include <mapnik/geom_util.hpp>
 #if defined(MAPNIK_MEMORY_MAPPED_FILE)
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
 #include <boost/interprocess/mapped_region.hpp>
 #include <boost/interprocess/streams/bufferstream.hpp>
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 #include <mapnik/mapped_memory_cache.hpp>
 #endif
+#include <mapnik/util/mapped_memory_file.hpp>
 
 // stl
 #include <sstream>
@@ -64,13 +65,16 @@
 using mapnik::datasource;
 using mapnik::parameters;
 
-DATASOURCE_PLUGIN(csv_datasource)
+DATASOURCE_PLUGIN_IMPL(csv_datasource_plugin, csv_datasource);
+DATASOURCE_PLUGIN_EXPORT(csv_datasource_plugin);
+DATASOURCE_PLUGIN_EMPTY_AFTER_LOAD(csv_datasource_plugin);
+DATASOURCE_PLUGIN_EMPTY_BEFORE_UNLOAD(csv_datasource_plugin);
 
 csv_datasource::csv_datasource(parameters const& params)
-: datasource(params),
-    desc_(csv_datasource::name(), *params.get<std::string>("encoding", "utf-8")),
-    ctx_(std::make_shared<mapnik::context_type>()),
-    tree_(nullptr)
+    : datasource(params)
+    , desc_(csv_datasource::name(), *params.get<std::string>("encoding", "utf-8"))
+    , ctx_(std::make_shared<mapnik::context_type>())
+    , tree_(nullptr)
 {
     row_limit_ = *params.get<mapnik::value_integer>("row_limit", 0);
     manual_headers_ = mapnik::util::trim_copy(*params.get<std::string>("headers", ""));
@@ -80,32 +84,35 @@ csv_datasource::csv_datasource(parameters const& params)
     if (quote_param)
     {
         auto val = mapnik::util::trim_copy(*quote_param);
-        if (!val.empty()) quote_ = val.front(); // we pick pick first non-space char
+        if (!val.empty())
+            quote_ = val.front(); // we pick pick first non-space char
     }
 
     auto separator_param = params.get<std::string>("separator");
     if (separator_param)
     {
         auto val = mapnik::util::trim_copy(*separator_param);
-        if (!val.empty()) separator_ = val.front();
+        if (!val.empty())
+            separator_ = val.front();
     }
 
-    boost::optional<std::string> ext = params.get<std::string>("extent");
+    const auto ext = params.get<std::string>("extent");
     if (ext && !ext->empty())
     {
         extent_initialized_ = extent_.from_string(*ext);
     }
 
-    boost::optional<std::string> inline_string = params.get<std::string>("inline");
+    const auto inline_string = params.get<std::string>("inline");
     if (inline_string)
     {
         inline_string_ = *inline_string;
     }
     else
     {
-        boost::optional<std::string> file = params.get<std::string>("file");
-        if (!file) throw mapnik::datasource_exception("CSV Plugin: missing <file> parameter");
-        boost::optional<std::string> base = params.get<std::string>("base");
+        const auto file = params.get<std::string>("file");
+        if (!file)
+            throw mapnik::datasource_exception("CSV Plugin: missing <file> parameter");
+        const auto base = params.get<std::string>("base");
         if (base)
             filename_ = *base + "/" + *file;
         else
@@ -120,59 +127,34 @@ csv_datasource::csv_datasource(parameters const& params)
     }
     else
     {
-#if defined (MAPNIK_MEMORY_MAPPED_FILE)
-        using file_source_type = boost::interprocess::ibufferstream;
-        file_source_type in;
-        mapnik::mapped_region_ptr mapped_region;
-        boost::optional<mapnik::mapped_region_ptr> memory =
-            mapnik::mapped_memory_cache::instance().find(filename_, true);
-        if (memory)
-        {
-            mapped_region = *memory;
-            in.buffer(static_cast<char*>(mapped_region->get_address()),mapped_region->get_size());
-        }
-        else
-        {
-            throw std::runtime_error("could not create file mapping for " + filename_);
-        }
-#elif defined (_WINDOWS)
-        std::ifstream in(mapnik::utf8_to_utf16(filename_),std::ios_base::in | std::ios_base::binary);
-        if (!in.is_open())
-        {
-            throw mapnik::datasource_exception("CSV Plugin: could not open: '" + filename_ + "'");
-        }
-#else
-        std::ifstream in(filename_.c_str(),std::ios_base::in | std::ios_base::binary);
-        if (!in.is_open())
-        {
-            throw mapnik::datasource_exception("CSV Plugin: could not open: '" + filename_ + "'");
-        }
-#endif
-        parse_csv(in);
+        mapnik::util::mapped_memory_file in_file{filename_};
+        parse_csv(in_file.file());
 
         if (has_disk_index_ && !extent_initialized_)
         {
             // read bounding box from *.index
-            using value_type = std::pair<std::size_t, std::size_t>;
+            using value_type = mapnik::util::index_record;
             std::ifstream index(filename_ + ".index", std::ios::binary);
-            if (!index) throw mapnik::datasource_exception("CSV Plugin: could not open: '" + filename_ + ".index'");
-            extent_ = mapnik::util::spatial_index<value_type,
-                                                  mapnik::filter_in_box,
-                                                  std::ifstream>::bounding_box(index);
+            if (!index)
+                throw mapnik::datasource_exception("CSV Plugin: could not open: '" + filename_ + ".index'");
+            auto ext_f = mapnik::util::spatial_index<value_type,
+                                                     mapnik::bounding_box_filter<float>,
+                                                     std::ifstream,
+                                                     mapnik::box2d<float>>::bounding_box(index);
+            extent_ = {ext_f.minx(), ext_f.miny(), ext_f.maxx(), ext_f.maxy()};
         }
-        //in.close(); no need to call close, rely on dtor
+        // in.close(); no need to call close, rely on dtor
     }
 }
 
 csv_datasource::~csv_datasource() {}
 
-void csv_datasource::parse_csv(std::istream & csv_file)
+void csv_datasource::parse_csv(std::istream& csv_file)
 {
     std::vector<item_type> boxes;
     csv_utils::csv_file_parser::parse_csv_and_boxes(csv_file, boxes);
 
-    std::for_each(headers_.begin(), headers_.end(),
-                  [ & ](std::string const& header){ ctx_->push(header); });
+    std::for_each(headers_.begin(), headers_.end(), [&](std::string const& header) { ctx_->push(header); });
 
     if (!has_disk_index_)
     {
@@ -181,18 +163,19 @@ void csv_datasource::parse_csv(std::istream & csv_file)
     }
 }
 
-void csv_datasource::add_feature(mapnik::value_integer index,
-                                 mapnik::csv_line const & values)
+void csv_datasource::add_feature(mapnik::value_integer index, mapnik::csv_line const& values)
 {
-    if (index != 1) return;
+    if (index != 1)
+        return;
 
     for (std::size_t i = 0; i < values.size(); ++i)
     {
         std::string const& header = headers_.at(i);
         std::string value = mapnik::util::trim_copy(values[i]);
         int value_length = value.length();
-        if (locator_.index == i && (locator_.type == csv_utils::geometry_column_locator::WKT
-                                    || locator_.type == csv_utils::geometry_column_locator::GEOJSON)) continue;
+        if (locator_.index == i && (locator_.type == csv_utils::geometry_column_locator::WKT ||
+                                    locator_.type == csv_utils::geometry_column_locator::GEOJSON))
+            continue;
 
         // First we detect likely strings,
         // then try parsing likely numbers,
@@ -218,19 +201,19 @@ void csv_datasource::add_feature(mapnik::value_integer index,
             if (has_dot || has_e)
             {
                 double float_val = 0.0;
-                if (mapnik::util::string2double(value,float_val))
+                if (mapnik::util::string2double(value, float_val))
                 {
                     matched = true;
-                    desc_.add_descriptor(mapnik::attribute_descriptor(header,mapnik::Double));
+                    desc_.add_descriptor(mapnik::attribute_descriptor(header, mapnik::Double));
                 }
             }
             else
             {
                 mapnik::value_integer int_val = 0;
-                if (mapnik::util::string2int(value,int_val))
+                if (mapnik::util::string2int(value, int_val))
                 {
                     matched = true;
-                    desc_.add_descriptor(mapnik::attribute_descriptor(header,mapnik::Integer));
+                    desc_.add_descriptor(mapnik::attribute_descriptor(header, mapnik::Integer));
                 }
             }
         }
@@ -251,7 +234,7 @@ void csv_datasource::add_feature(mapnik::value_integer index,
     }
 }
 
-const char * csv_datasource::name()
+const char* csv_datasource::name()
 {
     return "csv";
 }
@@ -271,20 +254,19 @@ mapnik::layer_descriptor csv_datasource::get_descriptor() const
     return desc_;
 }
 
-boost::optional<mapnik::datasource_geometry_t>
-csv_datasource::get_geometry_type_impl(std::istream & stream) const
+std::optional<mapnik::datasource_geometry_t> csv_datasource::get_geometry_type_impl(std::istream& stream) const
 {
-    boost::optional<mapnik::datasource_geometry_t> result;
+    std::optional<mapnik::datasource_geometry_t> result;
     if (tree_)
     {
         int multi_type = 0;
         auto itr = tree_->qbegin(boost::geometry::index::intersects(extent_));
         auto end = tree_->qend();
-        for (std::size_t count = 0; itr !=end &&  count < 5; ++itr, ++count)
+        for (std::size_t count = 0; itr != end && count < 5; ++itr, ++count)
         {
             csv_datasource::item_type const& item = *itr;
-            std::size_t file_offset = item.second.first;
-            std::size_t size = item.second.second;
+            std::uint64_t file_offset = item.second.first;
+            std::uint64_t size = item.second.second;
             stream.seekg(file_offset);
             std::vector<char> record;
             record.resize(size);
@@ -300,7 +282,7 @@ csv_datasource::get_geometry_type_impl(std::istream & stream) const
                     int type = static_cast<int>(*result);
                     if (multi_type > 0 && multi_type != type)
                     {
-                        result.reset(mapnik::datasource_geometry_t::Collection);
+                        result = mapnik::datasource_geometry_t::Collection;
                         return result;
                     }
                     multi_type = type;
@@ -308,30 +290,34 @@ csv_datasource::get_geometry_type_impl(std::istream & stream) const
             }
             catch (std::exception const& ex)
             {
-                if (strict_) throw ex;
-                else MAPNIK_LOG_ERROR(csv) << ex.what();
+                if (strict_)
+                    throw ex;
+                else
+                    MAPNIK_LOG_ERROR(csv) << ex.what();
             }
         }
     }
     else
     {
         // try reading *.index
-        using value_type = std::pair<std::size_t, std::size_t>;
+        using value_type = mapnik::util::index_record;
         std::ifstream index(filename_ + ".index", std::ios::binary);
-        if (!index) throw mapnik::datasource_exception("CSV Plugin: could not open: '" + filename_ + ".index'");
-
-        mapnik::filter_in_box filter(extent_);
+        if (!index)
+            throw mapnik::datasource_exception("CSV Plugin: could not open: '" + filename_ + ".index'");
+        mapnik::bounding_box_filter<float> filter{
+          mapnik::box2d<float>(extent_.minx(), extent_.miny(), extent_.maxx(), extent_.maxy())};
         std::vector<value_type> positions;
         mapnik::util::spatial_index<value_type,
-                                    mapnik::filter_in_box,
-                                    std::ifstream>::query_first_n(filter, index, positions, 5);
+                                    mapnik::bounding_box_filter<float>,
+                                    std::ifstream,
+                                    mapnik::box2d<float>>::query_first_n(filter, index, positions, 5);
         int multi_type = 0;
         for (auto const& val : positions)
         {
-            stream.seekg(val.first);
+            stream.seekg(val.off);
             std::vector<char> record;
-            record.resize(val.second);
-            stream.read(record.data(), val.second);
+            record.resize(val.size);
+            stream.read(record.data(), val.size);
             std::string str(record.begin(), record.end());
             try
             {
@@ -343,7 +329,7 @@ csv_datasource::get_geometry_type_impl(std::istream & stream) const
                     int type = static_cast<int>(*result);
                     if (multi_type > 0 && multi_type != type)
                     {
-                        result.reset(mapnik::datasource_geometry_t::Collection);
+                        result = mapnik::datasource_geometry_t::Collection;
                         return result;
                     }
                     multi_type = type;
@@ -351,23 +337,24 @@ csv_datasource::get_geometry_type_impl(std::istream & stream) const
             }
             catch (std::exception const& ex)
             {
-                if (strict_) throw ex;
-                else MAPNIK_LOG_ERROR(csv) << ex.what();
+                if (strict_)
+                    throw ex;
+                else
+                    MAPNIK_LOG_ERROR(csv) << ex.what();
             }
         }
-
     }
     return result;
 }
 
-boost::optional<mapnik::datasource_geometry_t> csv_datasource::get_geometry_type() const
+std::optional<mapnik::datasource_geometry_t> csv_datasource::get_geometry_type() const
 {
     if (inline_string_.empty())
     {
-#if defined (_WINDOWS)
-        std::ifstream in(mapnik::utf8_to_utf16(filename_),std::ios_base::in | std::ios_base::binary);
+#if defined(_WIN32)
+        std::ifstream in(mapnik::utf8_to_utf16(filename_), std::ios_base::in | std::ios_base::binary);
 #else
-        std::ifstream in(filename_.c_str(),std::ios_base::in | std::ios_base::binary);
+        std::ifstream in(filename_.c_str(), std::ios_base::in | std::ios_base::binary);
 #endif
         if (!in.is_open())
         {
@@ -398,8 +385,8 @@ mapnik::featureset_ptr csv_datasource::features(mapnik::query const& q) const
         if (!found_name)
         {
             std::ostringstream s;
-            s << "CSV Plugin: no attribute '" << name << "'. Valid attributes are: "
-              << boost::algorithm::join(headers_, ",") << ".";
+            s << "CSV Plugin: no attribute '" << name
+              << "'. Valid attributes are: " << boost::algorithm::join(headers_, ",") << ".";
             throw mapnik::datasource_exception(s.str());
         }
     }
@@ -410,25 +397,43 @@ mapnik::featureset_ptr csv_datasource::features(mapnik::query const& q) const
         if (tree_)
         {
             csv_featureset::array_type index_array;
-            tree_->query(boost::geometry::index::intersects(box),std::back_inserter(index_array));
-            std::sort(index_array.begin(),index_array.end(),
-                      [] (item_type const& item0, item_type const& item1)
-                      {
-                          return item0.second.first < item1.second.first;
-                      });
+            tree_->query(boost::geometry::index::intersects(box), std::back_inserter(index_array));
+            std::sort(index_array.begin(), index_array.end(), [](item_type const& item0, item_type const& item1) {
+                return item0.second.first < item1.second.first;
+            });
             if (inline_string_.empty())
             {
-                return std::make_shared<csv_featureset>(filename_, locator_, separator_, quote_, headers_, ctx_, std::move(index_array));
+                return std::make_shared<csv_featureset>(filename_,
+                                                        locator_,
+                                                        separator_,
+                                                        quote_,
+                                                        headers_,
+                                                        ctx_,
+                                                        std::move(index_array));
             }
             else
             {
-                return std::make_shared<csv_inline_featureset>(inline_string_, locator_, separator_, quote_, headers_, ctx_, std::move(index_array));
+                return std::make_shared<csv_inline_featureset>(inline_string_,
+                                                               locator_,
+                                                               separator_,
+                                                               quote_,
+                                                               headers_,
+                                                               ctx_,
+                                                               std::move(index_array));
             }
         }
         else if (has_disk_index_)
         {
-            mapnik::filter_in_box filter(q.get_bbox());
-            return std::make_shared<csv_index_featureset>(filename_, filter, locator_, separator_, quote_, headers_, ctx_);
+            auto const& bbox = q.get_bbox();
+            mapnik::bounding_box_filter<float> const filter(
+              mapnik::box2d<float>(bbox.minx(), bbox.miny(), bbox.maxx(), bbox.maxy()));
+            return std::make_shared<csv_index_featureset>(filename_,
+                                                          filter,
+                                                          locator_,
+                                                          separator_,
+                                                          quote_,
+                                                          headers_,
+                                                          ctx_);
         }
     }
     return mapnik::make_invalid_featureset();
