@@ -28,10 +28,10 @@
 #include <mapnik/params.hpp>
 #include <mapnik/query.hpp>
 #include <mapnik/feature.hpp>
-#include <mapnik/box2d.hpp>
+#include <mapnik/geometry/box2d.hpp>
 #include <mapnik/coord.hpp>
 #include <mapnik/feature_layer_desc.hpp>
-
+#include <mapnik/datasource_plugin.hpp>
 // boost
 #include <boost/optional.hpp>
 
@@ -42,19 +42,22 @@
 // gdal
 #include <gdal_priv.h>
 
+DATASOURCE_PLUGIN_DEF(gdal_datasource_plugin, gdal);
+
 class gdal_datasource : public mapnik::datasource
 {
-public:
+  public:
     gdal_datasource(mapnik::parameters const& params);
     virtual ~gdal_datasource();
-    mapnik::datasource::datasource_t type() const;
-    static const char * name();
-    mapnik::featureset_ptr features(mapnik::query const& q) const;
-    mapnik::featureset_ptr features_at_point(mapnik::coord2d const& pt, double tol = 0) const;
-    mapnik::box2d<double> envelope() const;
-    boost::optional<mapnik::datasource_geometry_t> get_geometry_type() const;
-    mapnik::layer_descriptor get_descriptor() const;
-private:
+    mapnik::datasource::datasource_t type() const override;
+    static const char* name();
+    mapnik::featureset_ptr features(mapnik::query const& q) const override;
+    mapnik::featureset_ptr features_at_point(mapnik::coord2d const& pt, double tol = 0) const override;
+    mapnik::box2d<double> envelope() const override;
+    std::optional<mapnik::datasource_geometry_t> get_geometry_type() const override;
+    mapnik::layer_descriptor get_descriptor() const override;
+
+  private:
     std::unique_ptr<GDALDataset, decltype(&GDALClose)> dataset_;
     mapnik::box2d<double> extent_;
     std::string dataset_name_;
@@ -66,7 +69,7 @@ private:
     double dy_;
     int nbands_;
     bool shared_dataset_;
-    boost::optional<double> nodata_value_;
+    std::optional<double> nodata_value_;
     double nodata_tolerance_;
     int64_t max_image_area_;
 };
