@@ -24,11 +24,11 @@
 #define GDAL_FEATURESET_HPP
 
 // mapnik
+#include <mapnik/feature.hpp>
 #include <mapnik/featureset.hpp>
 #include <mapnik/query.hpp>
 #include <mapnik/util/variant.hpp>
-// boost
-#include <boost/optional.hpp>
+#include <optional>
 
 class GDALDataset;
 class GDALRasterBand;
@@ -39,23 +39,18 @@ class gdal_featureset : public mapnik::Featureset
 {
     struct query_dispatch
     {
-        query_dispatch( gdal_featureset & featureset)
-            : featureset_(featureset) {}
+        query_dispatch(gdal_featureset& featureset)
+            : featureset_(featureset)
+        {}
 
-        mapnik::feature_ptr operator() (mapnik::query const& q) const
-        {
-            return featureset_.get_feature(q);
-        }
+        mapnik::feature_ptr operator()(mapnik::query const& q) const { return featureset_.get_feature(q); }
 
-        mapnik::feature_ptr operator() (mapnik::coord2d const& p) const
-        {
-            return featureset_.get_feature_at_point(p);
-        }
+        mapnik::feature_ptr operator()(mapnik::coord2d const& p) const { return featureset_.get_feature_at_point(p); }
 
-        gdal_featureset & featureset_;
+        gdal_featureset& featureset_;
     };
 
-public:
+  public:
     gdal_featureset(GDALDataset& dataset,
                     int band,
                     gdal_query q,
@@ -65,22 +60,22 @@ public:
                     int nbands,
                     double dx,
                     double dy,
-                    boost::optional<double> const& nodata,
+                    std::optional<double> const& nodata,
                     double nodata_tolerance,
                     int64_t max_image_area);
     virtual ~gdal_featureset();
     mapnik::feature_ptr next();
 
-private:
+  private:
     void find_best_overview(int bandNumber,
                             int ideal_width,
                             int ideal_height,
-                            int & current_width,
-                            int & current_height) const;
+                            int& current_width,
+                            int& current_height) const;
 
     mapnik::feature_ptr get_feature(mapnik::query const& q);
     mapnik::feature_ptr get_feature_at_point(mapnik::coord2d const& p);
-    GDALDataset & dataset_;
+    GDALDataset& dataset_;
     mapnik::context_ptr ctx_;
     int band_;
     gdal_query gquery_;
@@ -90,7 +85,7 @@ private:
     double dx_;
     double dy_;
     int nbands_;
-    boost::optional<double> nodata_value_;
+    std::optional<double> nodata_value_;
     double nodata_tolerance_;
     int64_t max_image_area_;
     bool first_;
