@@ -24,31 +24,34 @@
 #include "geojson_index_featureset.hpp"
 #include <mapnik/feature.hpp>
 #include <mapnik/feature_factory.hpp>
-#include <mapnik/json/feature_grammar.hpp>
 #include <mapnik/util/utf_conv_win.hpp>
-#include <mapnik/util/spatial_index.hpp>
-#include <mapnik/geometry_is_empty.hpp>
+#include <mapnik/util/conversions.hpp>
+#include <mapnik/geometry/is_empty.hpp>
+#include <mapnik/json/parse_feature.hpp>
+#include <mapnik/json/json_grammar_config.hpp>
 // stl
 #include <string>
 #include <vector>
 #include <fstream>
+#include <algorithm>
 
-geojson_index_featureset::geojson_index_featureset(std::string const& filename, mapnik::filter_in_box const& filter)
+geojson_index_featureset::geojson_index_featureset(std::string const& filename,
+                                                   mapnik::bounding_box_filter<float> const& filter)
     :
 #if defined(MAPNIK_MEMORY_MAPPED_FILE)
-    //
-#elif defined _WINDOWS
-    file_(_wfopen(mapnik::utf8_to_utf16(filename).c_str(), L"rb"), std::fclose),
+//
+#elif defined(_WIN32)
+    file_(_wfopen(mapnik::utf8_to_utf16(filename).c_str(), L"rb"), std::fclose)
+    ,
 #else
-    file_(std::fopen(filename.c_str(),"rb"), std::fclose),
+    file_(std::fopen(filename.c_str(), "rb"), std::fclose)
+    ,
 #endif
     ctx_(std::make_shared<mapnik::context_type>())
 {
-
-#if defined (MAPNIK_MEMORY_MAPPED_FILE)
-    boost::optional<mapnik::mapped_region_ptr> memory =
-        mapnik::mapped_memory_cache::instance().find(filename, true);
-    if (memory)
+#if defined(MAPNIK_MEMORY_MAPPED_FILE)
+    const auto memory = mapnik::mapped_memory_cache::instance().find(filename, true);
+    if (memory.has_value())
     {
         mapped_region_ = *memory;
     }
@@ -57,17 +60,24 @@ geojson_index_featureset::geojson_index_featureset(std::string const& filename,
         throw std::runtime_error("could not create file mapping for " + filename);
     }
 #else
-    if (!file_) throw std::runtime_error("Can't open " + filename);
+    if (!file_)
+        throw std::runtime_error("Can't open " + filename);
 #endif
     std::string indexname = filename + ".index";
     std::ifstream index(indexname.c_str(), std::ios::binary);
-    if (!index) throw mapnik::datasource_exception("GeoJSON Plugin: can't open index file " + indexname);
-    mapnik::util::spatial_index<value_type,
-                                mapnik::filter_in_box,
-                                std::ifstream>::query(filter, index, positions_);
+    if (!index)
+        throw mapnik::datasource_exception("GeoJSON Plugin: can't open index file " + indexname);
+    mapnik::util::spatial_index<value_type, mapnik::bounding_box_filter<float>, std::ifstream, mapnik::box2d<float>>::
+      query(filter, index, positions_);
 
-    std::sort(positions_.begin(), positions_.end(),
-              [](value_type const& lhs, value_type const& rhs) { return lhs.first < rhs.first;});
+    positions_.erase(std::remove_if(positions_.begin(),
+                                    positions_.end(),
+                                    [&](value_type const& pos) { return !pos.box.intersects(filter.box_); }),
+                     positions_.end());
+
+    std::sort(positions_.begin(), positions_.end(), [](value_type const& lhs, value_type const& rhs) {
+        return lhs.off < rhs.off;
+    });
     itr_ = positions_.begin();
 }
 
@@ -75,29 +85,24 @@ geojson_index_featureset::~geojson_index_featureset() {}
 
 mapnik::feature_ptr geojson_index_featureset::next()
 {
-    while( itr_ != positions_.end())
+    while (itr_ != positions_.end())
     {
         auto pos = *itr_++;
 #if defined(MAPNIK_MEMORY_MAPPED_FILE)
-        char const* start = (char const*)mapped_region_->get_address() + pos.first;
-        char const*  end = start + pos.second;
+        char const* start = static_cast<char const*>(mapped_region_->get_address()) + pos.off;
+        char const* end = start + pos.size;
 #else
-        std::fseek(file_.get(), pos.first, SEEK_SET);
+        std::fseek(file_.get(), pos.off, SEEK_SET);
         std::vector<char> record;
-        record.resize(pos.second);
-        std::fread(record.data(), pos.second, 1, file_.get());
+        record.resize(pos.size);
+        auto count = std::fread(record.data(), pos.size, 1, file_.get());
         auto const* start = record.data();
-        auto const*  end = start + record.size();
+        auto const* end = (count == 1) ? start + record.size() : start;
 #endif
         static const mapnik::transcoder tr("utf8");
-        static const mapnik::json::feature_grammar<char const*, mapnik::feature_impl> grammar(tr);
-        using namespace boost::spirit;
-        standard::space_type space;
         mapnik::feature_ptr feature(mapnik::feature_factory::create(ctx_, feature_id_++));
-        if (!qi::phrase_parse(start, end, (grammar)(boost::phoenix::ref(*feature)), space) || start != end)
-        {
-            throw std::runtime_error("Failed to parse GeoJSON feature");
-        }
+        using mapnik::json::grammar::iterator_type;
+        mapnik::json::parse_feature(start, end, *feature, tr); // throw on failure
         // skip empty geometries
         if (mapnik::geometry::is_empty(feature->get_geometry()))
             continue;
