@@ -28,19 +28,20 @@
 #include <mapnik/params.hpp>
 #include <mapnik/query.hpp>
 #include <mapnik/feature.hpp>
-#include <mapnik/box2d.hpp>
+#include <mapnik/geometry/box2d.hpp>
 #include <mapnik/coord.hpp>
 #include <mapnik/feature_layer_desc.hpp>
 #include <mapnik/unicode.hpp>
-#include <mapnik/value_types.hpp>
+#include <mapnik/value/types.hpp>
 #include <mapnik/attribute.hpp>
+#include <mapnik/datasource_plugin.hpp>
 
 // boost
 #include <boost/optional.hpp>
-#include <boost/regex.hpp>
 
 // stl
 #include <memory>
+#include <regex>
 #include <vector>
 #include <string>
 
@@ -48,56 +49,62 @@
 #include "resultset.hpp"
 #include "cursorresultset.hpp"
 
-using mapnik::transcoder;
-using mapnik::datasource;
-using mapnik::feature_style_context_map;
-using mapnik::processor_context_ptr;
 using mapnik::box2d;
-using mapnik::layer_descriptor;
-using mapnik::featureset_ptr;
-using mapnik::feature_ptr;
-using mapnik::query;
-using mapnik::parameters;
 using mapnik::coord2d;
+using mapnik::datasource;
+using mapnik::feature_ptr;
+using mapnik::feature_style_context_map;
+using mapnik::featureset_ptr;
+using mapnik::layer_descriptor;
+using mapnik::parameters;
+using mapnik::processor_context_ptr;
+using mapnik::query;
+using mapnik::transcoder;
 
-using CnxPool_ptr = std::shared_ptr< ConnectionManager::PoolType>;
+using CnxPool_ptr = std::shared_ptr<ConnectionManager::PoolType>;
 
+DATASOURCE_PLUGIN_DEF(postgis_datasource_plugin, postgis);
 class postgis_datasource : public datasource
 {
-public:
-    postgis_datasource(const parameters &params);
+  public:
+    postgis_datasource(const parameters& params);
     ~postgis_datasource();
-    mapnik::datasource::datasource_t type() const;
-    static const char * name();
-    processor_context_ptr get_context(feature_style_context_map &) const;
-    featureset_ptr features_with_context(query const& q, processor_context_ptr ctx) const;
-    featureset_ptr features(query const& q) const;
-    featureset_ptr features_at_point(coord2d const& pt, double tol = 0) const;
-    mapnik::box2d<double> envelope() const;
-    boost::optional<mapnik::datasource_geometry_t> get_geometry_type() const;
-    layer_descriptor get_descriptor() const;
+    mapnik::datasource::datasource_t type() const override;
+    static const char* name();
+    processor_context_ptr get_context(feature_style_context_map&) const override;
+    featureset_ptr features_with_context(query const& q, processor_context_ptr ctx) const override;
+    featureset_ptr features(query const& q) const override;
+    featureset_ptr features_at_point(coord2d const& pt, double tol = 0) const override;
+    mapnik::box2d<double> envelope() const override;
+    std::optional<mapnik::datasource_geometry_t> get_geometry_type() const override;
+    layer_descriptor get_descriptor() const override;
 
-private:
+  private:
     std::string sql_bbox(box2d<double> const& env) const;
     std::string populate_tokens(std::string const& sql,
                                 double scale_denom,
                                 box2d<double> const& env,
                                 double pixel_width,
                                 double pixel_height,
-                                mapnik::attributes const& vars) const;
+                                mapnik::attributes const& vars,
+                                bool intersect = true) const;
     std::string populate_tokens(std::string const& sql) const;
-    std::shared_ptr<IResultSet> get_resultset(std::shared_ptr<Connection> &conn, std::string const& sql, CnxPool_ptr const& pool, processor_context_ptr ctx= processor_context_ptr()) const;
+    void append_geometry_table(std::ostream& os) const;
+    std::shared_ptr<IResultSet> get_resultset(std::shared_ptr<Connection>& conn,
+                                              std::string const& sql,
+                                              CnxPool_ptr const& pool,
+                                              processor_context_ptr ctx = processor_context_ptr()) const;
     static const std::string GEOMETRY_COLUMNS;
     static const std::string SPATIAL_REF_SYS;
-    static const double FMAX;
 
     const std::string uri_;
     const std::string username_;
     const std::string password_;
     const std::string table_;
-    std::string schema_;
-    std::string geometry_table_;
+    const std::string geometry_table_;
     const std::string geometry_field_;
+    std::string parsed_schema_;
+    std::string parsed_table_;
     std::string key_field_;
     mapnik::value_integer cursor_fetch_size_;
     mapnik::value_integer row_limit_;
@@ -109,10 +116,6 @@ private:
     bool simplify_geometries_;
     layer_descriptor desc_;
     ConnectionCreator<Connection> creator_;
-    const std::string bbox_token_;
-    const std::string scale_denom_token_;
-    const std::string pixel_width_token_;
-    const std::string pixel_height_token_;
     int pool_max_size_;
     bool persist_connection_;
     bool extent_from_subquery_;
@@ -123,10 +126,9 @@ private:
     mapnik::value_double twkb_rounding_adjustment_;
     mapnik::value_double simplify_snap_ratio_;
     mapnik::value_double simplify_dp_ratio_;
-    mapnik::value_double simplify_prefilter_;
     bool simplify_dp_preserve_;
     mapnik::value_double simplify_clip_resolution_;
-    boost::regex pattern_;
+    std::regex re_tokens_;
     int intersect_min_scale_;
     int intersect_max_scale_;
     bool key_field_as_attribute_;
