@@ -28,34 +28,28 @@
 #include <mapnik/params.hpp>
 #include <mapnik/query.hpp>
 #include <mapnik/feature.hpp>
-#include <mapnik/box2d.hpp>
+#include <mapnik/geometry/box2d.hpp>
 #include <mapnik/coord.hpp>
 #include <mapnik/feature_layer_desc.hpp>
+#include <mapnik/datasource_plugin.hpp>
 
-// boost
-#include <boost/optional.hpp>
-#include <memory>
-
-// stl
-#include <vector>
-#include <string>
-
+DATASOURCE_PLUGIN_DEF(raster_datasource_plugin, raster);
 
 class raster_datasource : public mapnik::datasource
 {
-public:
+  public:
     raster_datasource(const mapnik::parameters& params);
     virtual ~raster_datasource();
-    datasource::datasource_t type() const;
-    static const char * name();
-    mapnik::featureset_ptr features(const mapnik::query& q) const;
-    mapnik::featureset_ptr features_at_point(mapnik::coord2d const& pt, double tol = 0) const;
-    mapnik::box2d<double> envelope() const;
-    boost::optional<mapnik::datasource_geometry_t> get_geometry_type() const;
-    mapnik::layer_descriptor get_descriptor() const;
+    datasource::datasource_t type() const override;
+    static const char* name();
+    mapnik::featureset_ptr features(const mapnik::query& q) const override;
+    mapnik::featureset_ptr features_at_point(mapnik::coord2d const& pt, double tol = 0) const override;
+    mapnik::box2d<double> envelope() const override;
+    std::optional<mapnik::datasource_geometry_t> get_geometry_type() const override;
+    mapnik::layer_descriptor get_descriptor() const override;
     bool log_enabled() const;
 
-private:
+  private:
     mapnik::layer_descriptor desc_;
     std::string filename_;
     std::string format_;
