@@ -34,41 +34,47 @@
 #include <mapnik/wkb.hpp>
 #include <mapnik/util/trim.hpp>
 #include <mapnik/util/fs.hpp>
-#include <mapnik/geometry_is_empty.hpp>
+#include <mapnik/geometry/is_empty.hpp>
 
 // boost
 #include <boost/algorithm/string.hpp>
 #include <boost/tokenizer.hpp>
 
+using mapnik::attribute_descriptor;
 using mapnik::box2d;
 using mapnik::coord2d;
-using mapnik::query;
+using mapnik::datasource;
+using mapnik::datasource_exception;
 using mapnik::featureset_ptr;
 using mapnik::layer_descriptor;
-using mapnik::attribute_descriptor;
-using mapnik::datasource_exception;
-using mapnik::datasource;
 using mapnik::parameters;
+using mapnik::query;
 
-DATASOURCE_PLUGIN(sqlite_datasource)
+DATASOURCE_PLUGIN_IMPL(sqlite_datasource_plugin, sqlite_datasource);
+DATASOURCE_PLUGIN_EXPORT(sqlite_datasource_plugin);
+DATASOURCE_PLUGIN_EMPTY_AFTER_LOAD(sqlite_datasource_plugin);
+DATASOURCE_PLUGIN_EMPTY_BEFORE_UNLOAD(sqlite_datasource_plugin);
 
 sqlite_datasource::sqlite_datasource(parameters const& params)
-    : datasource(params),
-      extent_(),
-      extent_initialized_(false),
-      type_(datasource::Vector),
-      table_(*params.get<std::string>("table", "")),
-      fields_(*params.get<std::string>("fields", "*")),
-      metadata_(*params.get<std::string>("metadata", "")),
-      geometry_table_(*params.get<std::string>("geometry_table", "")),
-      geometry_field_(*params.get<std::string>("geometry_field", "")),
-      index_table_(*params.get<std::string>("index_table", "")),
-      key_field_(*params.get<std::string>("key_field", "")),
-      row_offset_(*params.get<mapnik::value_integer>("row_offset", 0)),
-      row_limit_(*params.get<mapnik::value_integer>("row_limit", 0)),
-      intersects_token_("!intersects!"),
-      desc_(sqlite_datasource::name(), *params.get<std::string>("encoding", "utf-8")),
-      format_(mapnik::wkbAuto)
+    : datasource(params)
+    , extent_()
+    , extent_initialized_(false)
+    , type_(datasource::Vector)
+    , table_(*params.get<std::string>("table", ""))
+    , fields_(*params.get<std::string>("fields", "*"))
+    , metadata_(*params.get<std::string>("metadata", ""))
+    , geometry_table_(*params.get<std::string>("geometry_table", ""))
+    , geometry_field_(*params.get<std::string>("geometry_field", ""))
+    , index_table_(*params.get<std::string>("index_table", ""))
+    , key_field_(*params.get<std::string>("key_field", ""))
+    , row_offset_(*params.get<mapnik::value_integer>("row_offset", 0))
+    , row_limit_(*params.get<mapnik::value_integer>("row_limit", 0))
+    , intersects_token_("!intersects!")
+    , pixel_width_token_("!pixel_width!")
+    , pixel_height_token_("!pixel_height!")
+    , desc_(sqlite_datasource::name(), *params.get<std::string>("encoding", "utf-8"))
+    , format_(mapnik::wkbAuto)
+    , twkb_encoding_(false)
 {
     /* TODO
        - throw if no primary key but spatial index is present?
@@ -80,10 +86,11 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     mapnik::progress_timer __stats__(std::clog, "sqlite_datasource::init");
 #endif
 
-    boost::optional<std::string> file = params.get<std::string>("file");
-    if (! file) throw datasource_exception("Sqlite Plugin: missing <file> parameter");
+    const auto file = params.get<std::string>("file");
+    if (!file)
+        throw datasource_exception("Sqlite Plugin: missing <file> parameter");
 
-    boost::optional<std::string> base = params.get<std::string>("base");
+    const auto base = params.get<std::string>("base");
     if (base)
         dataset_name_ = *base + "/" + *file;
     else
@@ -99,11 +106,12 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     // TODO - remove this option once all datasources have an indexing api
     bool auto_index = *params.get<mapnik::boolean_type>("auto_index", true);
 
-    boost::optional<std::string> ext  = params.get<std::string>("extent");
-    if (ext) extent_initialized_ = extent_.from_string(*ext);
+    const auto ext = params.get<std::string>("extent");
+    if (ext.has_value())
+        extent_initialized_ = extent_.from_string(*ext);
 
-    boost::optional<std::string> wkb = params.get<std::string>("wkb_format");
-    if (wkb)
+    const auto wkb = params.get<std::string>("wkb_format");
+    if (wkb.has_value())
     {
         if (*wkb == "spatialite")
         {
@@ -113,6 +121,11 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
         {
             format_ = mapnik::wkbGeneric;
         }
+        else if (*wkb == "twkb")
+        {
+            format_ = mapnik::wkbGeneric;
+            twkb_encoding_ = true;
+        }
         else
         {
             format_ = mapnik::wkbAuto;
@@ -126,14 +139,14 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     // databases are relative to directory containing dataset_name_.  Sqlite
     // will default to attaching from cwd.  Typicaly usage means that the
     // map loader will produce full paths here.
-    boost::optional<std::string> attachdb = params.get<std::string>("attachdb");
-    if (attachdb)
+    const auto attachdb = params.get<std::string>("attachdb");
+    if (attachdb.has_value())
     {
         parse_attachdb(*attachdb);
     }
 
-    boost::optional<std::string> initdb = params.get<std::string>("initdb");
-    if (initdb)
+    const auto initdb = params.get<std::string>("initdb");
+    if (initdb.has_value())
     {
         init_statements_.push_back(*initdb);
     }
@@ -141,34 +154,32 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     // now actually create the connection and start executing setup sql
     dataset_ = std::make_shared<sqlite_connection>(dataset_name_);
 
-    boost::optional<mapnik::value_integer> table_by_index = params.get<mapnik::value_integer>("table_by_index");
+    const auto table_by_index = params.get<mapnik::value_integer>("table_by_index");
 
     int passed_parameters = 0;
     passed_parameters += params.get<std::string>("table") ? 1 : 0;
-    passed_parameters += table_by_index ? 1 : 0;
+    passed_parameters += table_by_index.has_value() ? 1 : 0;
 
     if (passed_parameters > 1)
     {
         throw datasource_exception("SQLite Plugin: you can only select an by name "
                                    "('table' parameter), by number ('table_by_index' parameter), "
-                                   "do not supply 2 or more of them at the same time" );
+                                   "do not supply 2 or more of them at the same time");
     }
 
     if (table_by_index)
     {
         std::vector<std::string> tables;
-        sqlite_utils::get_tables(dataset_,tables);
+        sqlite_utils::get_tables(dataset_, tables);
         if (*table_by_index < 0 || *table_by_index >= static_cast<int>(tables.size()))
         {
             std::ostringstream s;
-            s << "SQLite Plugin: only "
-              << tables.size()
-              << " table(s) exist, cannot find table by index '" << *table_by_index << "'";
+            s << "SQLite Plugin: only " << tables.size() << " table(s) exist, cannot find table by index '"
+              << *table_by_index << "'";
 
             throw datasource_exception(s.str());
         }
         table_ = tables[*table_by_index];
-
     }
 
     if (table_.empty())
@@ -199,8 +210,8 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     }
 
     // Execute init_statements_
-    for (std::vector<std::string>::const_iterator iter = init_statements_.begin();
-         iter != init_statements_.end(); ++iter)
+    for (std::vector<std::string>::const_iterator iter = init_statements_.begin(); iter != init_statements_.end();
+         ++iter)
     {
         MAPNIK_LOG_DEBUG(sqlite) << "sqlite_datasource: Execute init sql=" << *iter;
 
@@ -211,13 +222,9 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     if (using_subquery_)
     {
         std::ostringstream s;
-        std::string query = populate_tokens(table_);
+        std::string query = populate_tokens(table_, 0, 0);
         s << "SELECT " << fields_ << " FROM (" << query << ") LIMIT 1";
-        found_types_via_subquery = sqlite_utils::detect_types_from_subquery(
-            s.str(),
-            geometry_field_,
-            desc_,
-            dataset_);
+        found_types_via_subquery = sqlite_utils::detect_types_from_subquery(s.str(), geometry_field_, desc_, dataset_);
     }
 
     // TODO - consider removing this
@@ -226,14 +233,10 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
         desc_.add_descriptor(attribute_descriptor("rowid", mapnik::Integer));
     }
 
-    bool found_table = sqlite_utils::table_info(key_field_,
-                                                found_types_via_subquery,
-                                                geometry_field_,
-                                                geometry_table_,
-                                                desc_,
-                                                dataset_);
+    bool found_table =
+      sqlite_utils::table_info(key_field_, found_types_via_subquery, geometry_field_, geometry_table_, desc_, dataset_);
 
-    if (! found_table)
+    if (!found_table)
     {
         std::ostringstream s;
         s << "Sqlite Plugin: could not query table '" << geometry_table_ << "'";
@@ -244,10 +247,11 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
 
         // report get available tables
         std::vector<std::string> tables;
-        sqlite_utils::get_tables(dataset_,tables);
+        sqlite_utils::get_tables(dataset_, tables);
         if (tables.size() > 0)
         {
-            s << " (available tables for " << dataset_name_ << " are: '" << boost::algorithm::join(tables, ", ") << "')";
+            s << " (available tables for " << dataset_name_ << " are: '" << boost::algorithm::join(tables, ", ")
+              << "')";
         }
 
         throw datasource_exception(s.str());
@@ -256,9 +260,8 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     if (geometry_field_.empty())
     {
         std::ostringstream s;
-        s << "Sqlite Plugin: unable to detect the column "
-          << "containing a valid geometry on table '" << geometry_table_ << "'. "
-          << "Please provide a column name by passing the 'geometry_field' option "
+        s << "Sqlite Plugin: unable to detect the column " << "containing a valid geometry on table '"
+          << geometry_table_ << "'. " << "Please provide a column name by passing the 'geometry_field' option "
           << "or indicate a different spatial table to use by passing the 'geometry_table' option";
         throw datasource_exception(s.str());
     }
@@ -267,7 +270,7 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
     {
         // Generate implicit index_table name - need to do this after
         // we have discovered meta-data or else we don't know the column name
-        index_table_ = sqlite_utils::index_for_table(geometry_table_,geometry_field_);
+        index_table_ = sqlite_utils::index_for_table(geometry_table_, geometry_field_);
     }
 
     std::string index_db = sqlite_utils::index_for_db(dataset_name_);
@@ -285,27 +288,23 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
             dataset_->execute("attach database '" + index_db + "' as " + index_table_);
             index_db_attached = true;
         }
-        has_spatial_index_ = sqlite_utils::has_rtree(index_table_,dataset_);
+        has_spatial_index_ = sqlite_utils::has_rtree(index_table_, dataset_);
 
         if (!has_spatial_index_ && auto_index)
         {
-            if (! key_field_.empty())
+            if (!key_field_.empty())
             {
                 std::ostringstream query;
-                query << "SELECT "
-                      << geometry_field_
-                      << "," << key_field_
-                      << " FROM ("
-                      << geometry_table_ << ")";
+                query << "SELECT " << geometry_field_ << "," << key_field_ << " FROM (" << geometry_table_ << ")";
 
 #ifdef MAPNIK_STATS
                 mapnik::progress_timer __stats2__(std::clog, "sqlite_datasource::init(create_spatial_index)");
 #endif
 
                 std::shared_ptr<sqlite_resultset> rs = dataset_->execute_query(query.str());
-                if (sqlite_utils::create_spatial_index(index_db,index_table_,rs))
+                if (sqlite_utils::create_spatial_index(index_db, index_table_, rs))
                 {
-                    //extent_initialized_ = true;
+                    // extent_initialized_ = true;
                     has_spatial_index_ = true;
                     if (!index_db_attached && mapnik::util::exists(index_db))
                     {
@@ -316,24 +315,21 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
             else
             {
                 std::ostringstream s;
-                s << "Sqlite Plugin: could not generate spatial index"
-                  << " for table '" << geometry_table_ << "'"
-                  << " as no primary key can be detected."
-                  << " You should either declare an INTEGER PRIMARY KEY"
-                  << " or set the 'key_field' option to force a"
-                  << " given field to be used as the primary key";
+                s << "Sqlite Plugin: could not generate spatial index" << " for table '" << geometry_table_ << "'"
+                  << " as no primary key can be detected." << " You should either declare an INTEGER PRIMARY KEY"
+                  << " or set the 'key_field' option to force a" << " given field to be used as the primary key";
                 throw datasource_exception(s.str());
             }
         }
     }
 
-    if (! extent_initialized_)
+    if (!extent_initialized_)
     {
 #ifdef MAPNIK_STATS
         mapnik::progress_timer __stats2__(std::clog, "sqlite_datasource::init(detect_extent)");
 #endif
         // TODO - clean this up - reducing arguments
-        std::string query = populate_tokens(table_);
+        std::string query = populate_tokens(table_, 0, 0);
         if (!sqlite_utils::detect_extent(dataset_,
                                          has_spatial_index_,
                                          extent_,
@@ -345,18 +341,17 @@ sqlite_datasource::sqlite_datasource(parameters const& params)
                                          query))
         {
             std::ostringstream s;
-            s << "Sqlite Plugin: extent could not be determined for table '"
-              << geometry_table_ << "' and geometry field '" << geometry_field_ << "'"
+            s << "Sqlite Plugin: extent could not be determined for table '" << geometry_table_
+              << "' and geometry field '" << geometry_field_ << "'"
               << " because an rtree spatial index is missing or empty."
               << " - either set the table 'extent' or create an rtree spatial index";
 
             throw datasource_exception(s.str());
         }
     }
-
 }
 
-std::string sqlite_datasource::populate_tokens(std::string const& sql) const
+std::string sqlite_datasource::populate_tokens(std::string const& sql, double pixel_width, double pixel_height) const
 {
     std::string populated_sql = sql;
     if (boost::algorithm::ifind_first(populated_sql, intersects_token_))
@@ -364,21 +359,30 @@ std::string sqlite_datasource::populate_tokens(std::string const& sql) const
         // replace with dummy comparison that is true
         boost::algorithm::ireplace_first(populated_sql, intersects_token_, "1=1");
     }
+    if (boost::algorithm::icontains(sql, pixel_width_token_))
+    {
+        std::ostringstream ss;
+        ss << pixel_width;
+        boost::algorithm::replace_all(populated_sql, pixel_width_token_, ss.str());
+    }
+    if (boost::algorithm::icontains(sql, pixel_height_token_))
+    {
+        std::ostringstream ss;
+        ss << pixel_height;
+        boost::algorithm::replace_all(populated_sql, pixel_height_token_, ss.str());
+    }
     return populated_sql;
 }
 
-sqlite_datasource::~sqlite_datasource()
-{
-}
+sqlite_datasource::~sqlite_datasource() {}
 
 void sqlite_datasource::parse_attachdb(std::string const& attachdb) const
 {
     boost::char_separator<char> sep(",");
-    boost::tokenizer<boost::char_separator<char> > tok(attachdb, sep);
+    boost::tokenizer<boost::char_separator<char>> tok(attachdb, sep);
 
     // The attachdb line is a comma sparated list of [dbname@]filename
-    for (boost::tokenizer<boost::char_separator<char> >::iterator beg = tok.begin();
-         beg != tok.end(); ++beg)
+    for (boost::tokenizer<boost::char_separator<char>>::iterator beg = tok.begin(); beg != tok.end(); ++beg)
     {
         std::string const& spec(*beg);
         size_t atpos = spec.find('@');
@@ -395,7 +399,7 @@ void sqlite_datasource::parse_attachdb(std::string const& attachdb) const
         // Normalize the filename and make it relative to dataset_name_
         if (filename.compare(":memory:") != 0 && mapnik::util::is_relative(filename))
         {
-            filename = mapnik::util::make_relative(filename,dataset_name_);
+            filename = mapnik::util::make_relative(filename, dataset_name_);
         }
 
         // And add an init_statement_
@@ -403,7 +407,7 @@ void sqlite_datasource::parse_attachdb(std::string const& attachdb) const
     }
 }
 
-const char * sqlite_datasource::name()
+const char* sqlite_datasource::name()
 {
     return "sqlite";
 }
@@ -418,19 +422,18 @@ box2d<double> sqlite_datasource::envelope() const
     return extent_;
 }
 
-boost::optional<mapnik::datasource_geometry_t> sqlite_datasource::get_geometry_type() const
+std::optional<mapnik::datasource_geometry_t> sqlite_datasource::get_geometry_type() const
 {
 #ifdef MAPNIK_STATS
     mapnik::progress_timer __stats__(std::clog, "sqlite_datasource::get_geometry_type");
 #endif
 
-    boost::optional<mapnik::datasource_geometry_t> result;
+    std::optional<mapnik::datasource_geometry_t> result;
     if (dataset_)
     {
         // get geometry type by querying first features
         std::ostringstream s;
-        s << "SELECT " << geometry_field_
-          << " FROM " << geometry_table_;
+        s << "SELECT " << geometry_field_ << " FROM " << geometry_table_;
         if (row_limit_ > 0 && row_limit_ < 5)
         {
             s << " LIMIT " << row_limit_;
@@ -444,11 +447,15 @@ boost::optional<mapnik::datasource_geometry_t> sqlite_datasource::get_geometry_t
         while (rs->is_valid() && rs->step_next())
         {
             int size;
-            const char* data = (const char*) rs->column_blob(0, size);
+            const char* data = (const char*)rs->column_blob(0, size);
             if (data)
             {
+                mapnik::geometry::geometry<double> geom;
 
-                mapnik::geometry::geometry<double> geom = mapnik::geometry_utils::from_wkb(data, size, format_);
+                if (twkb_encoding_)
+                    geom = mapnik::geometry_utils::from_twkb(data, size);
+                else
+                    geom = mapnik::geometry_utils::from_wkb(data, size, format_);
                 if (mapnik::geometry::is_empty(geom))
                 {
                     continue;
@@ -459,7 +466,7 @@ boost::optional<mapnik::datasource_geometry_t> sqlite_datasource::get_geometry_t
                     int type = static_cast<int>(*result);
                     if (multi_type > 0 && multi_type != type)
                     {
-                        result.reset(mapnik::datasource_geometry_t::Collection);
+                        result = mapnik::datasource_geometry_t::Collection;
                         return result;
                     }
                     multi_type = type;
@@ -487,6 +494,10 @@ featureset_ptr sqlite_datasource::features(query const& q) const
         mapnik::box2d<double> const& e = q.get_bbox();
 
         std::ostringstream s;
+
+        const double px_gw = 1.0 / std::get<0>(q.resolution());
+        const double px_gh = 1.0 / std::get<1>(q.resolution());
+
         mapnik::context_ptr ctx = std::make_shared<mapnik::context_type>();
 
         s << "SELECT " << geometry_field_;
@@ -499,10 +510,10 @@ featureset_ptr sqlite_datasource::features(query const& q) const
         std::set<std::string>::const_iterator pos = props.begin();
         std::set<std::string>::const_iterator end = props.end();
 
-        for ( ;pos != end;++pos)
+        for (; pos != end; ++pos)
         {
             // TODO - should we restrict duplicate key query?
-            //if (*pos != key_field_)
+            // if (*pos != key_field_)
             s << ",[" << *pos << "]";
             ctx->push(*pos);
         }
@@ -510,7 +521,7 @@ featureset_ptr sqlite_datasource::features(query const& q) const
 
         std::string query(table_);
 
-        if (! key_field_.empty() && has_spatial_index_)
+        if (!key_field_.empty() && has_spatial_index_)
         {
             // TODO - debug warn if fails
             sqlite_utils::apply_spatial_filter(query,
@@ -521,12 +532,10 @@ featureset_ptr sqlite_datasource::features(query const& q) const
                                                geometry_table_,
                                                intersects_token_);
         }
-        else
-        {
-            query = populate_tokens(table_);
-        }
 
-        s << query ;
+        query = populate_tokens(query, px_gw, px_gh);
+
+        s << query;
 
         if (row_limit_ > 0)
         {
@@ -543,12 +552,13 @@ featureset_ptr sqlite_datasource::features(query const& q) const
         std::shared_ptr<sqlite_resultset> rs(dataset_->execute_query(s.str()));
 
         return std::make_shared<sqlite_featureset>(rs,
-                                                     ctx,
-                                                     desc_.get_encoding(),
-                                                     e,
-                                                     format_,
-                                                     has_spatial_index_,
-                                                     using_subquery_);
+                                                   ctx,
+                                                   desc_.get_encoding(),
+                                                   e,
+                                                   format_,
+                                                   twkb_encoding_,
+                                                   has_spatial_index_,
+                                                   using_subquery_);
     }
 
     return mapnik::make_invalid_featureset();
@@ -590,7 +600,7 @@ featureset_ptr sqlite_datasource::features_at_point(coord2d const& pt, double to
 
         std::string query(table_);
 
-        if (! key_field_.empty() && has_spatial_index_)
+        if (!key_field_.empty() && has_spatial_index_)
         {
             // TODO - debug warn if fails
             sqlite_utils::apply_spatial_filter(query,
@@ -601,12 +611,10 @@ featureset_ptr sqlite_datasource::features_at_point(coord2d const& pt, double to
                                                geometry_table_,
                                                intersects_token_);
         }
-        else
-        {
-            query = populate_tokens(table_);
-        }
 
-        s << query ;
+        query = populate_tokens(query, 0, 0);
+
+        s << query;
 
         if (row_limit_ > 0)
         {
@@ -623,12 +631,13 @@ featureset_ptr sqlite_datasource::features_at_point(coord2d const& pt, double to
         std::shared_ptr<sqlite_resultset> rs(dataset_->execute_query(s.str()));
 
         return std::make_shared<sqlite_featureset>(rs,
-                                                     ctx,
-                                                     desc_.get_encoding(),
-                                                     e,
-                                                     format_,
-                                                     has_spatial_index_,
-                                                     using_subquery_);
+                                                   ctx,
+                                                   desc_.get_encoding(),
+                                                   e,
+                                                   format_,
+                                                   twkb_encoding_,
+                                                   has_spatial_index_,
+                                                   using_subquery_);
     }
 
     return mapnik::make_invalid_featureset();
