@@ -35,29 +35,29 @@
 // sqlite
 #include "sqlite_resultset.hpp"
 
-
 class sqlite_featureset : public mapnik::Featureset
 {
-public:
+  public:
     sqlite_featureset(std::shared_ptr<sqlite_resultset> rs,
                       mapnik::context_ptr const& ctx,
                       std::string const& encoding,
                       mapnik::box2d<double> const& bbox,
                       mapnik::wkbFormat format,
+                      bool twkb_encoding,
                       bool spatial_index,
                       bool using_subquery);
     virtual ~sqlite_featureset();
     mapnik::feature_ptr next();
 
-private:
+  private:
     std::shared_ptr<sqlite_resultset> rs_;
     mapnik::context_ptr ctx_;
     const std::unique_ptr<mapnik::transcoder> tr_;
     mapnik::box2d<double> bbox_;
     mapnik::wkbFormat format_;
+    bool twkb_encoding_;
     bool spatial_index_;
     bool using_subquery_;
-
 };
 
 #endif // MAPNIK_SQLITE_FEATURESET_HPP
