@@ -34,10 +34,11 @@
 #include <mapnik/pixel_position.hpp>
 #include <mapnik/renderer_common/process_point_symbolizer.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_trans_affine.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 // stl
 #include <string>
@@ -46,23 +47,23 @@
 
 namespace mapnik {
 
-template <typename T0, typename T1>
-void agg_renderer<T0,T1>::process(point_symbolizer const& sym,
-                              mapnik::feature_impl & feature,
-                              proj_transform const& prj_trans)
+template<typename T0, typename T1>
+void agg_renderer<T0, T1>::process(point_symbolizer const& sym,
+                                   mapnik::feature_impl& feature,
+                                   proj_transform const& prj_trans)
 {
     composite_mode_e comp_op = get<composite_mode_e>(sym, keys::comp_op, feature, common_.vars_, src_over);
 
     render_point_symbolizer(
-        sym, feature, prj_trans, common_,
-        [&](pixel_position const& pos, marker const& marker,
-            agg::trans_affine const& tr, double opacity) {
-            render_marker(pos, marker, tr, opacity, comp_op);
-        });
+      sym,
+      feature,
+      prj_trans,
+      common_,
+      [&](pixel_position const& pos, marker const& marker, agg::trans_affine const& tr, double opacity) {
+          render_marker(pos, marker, tr, opacity, comp_op);
+      });
 }
 
-template void agg_renderer<image_rgba8>::process(point_symbolizer const&,
-                                              mapnik::feature_impl &,
-                                              proj_transform const&);
+template void agg_renderer<image_rgba8>::process(point_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-}
+} // namespace mapnik
