@@ -23,27 +23,24 @@
 #if defined(HAVE_CAIRO)
 
 // mapnik
-#include <mapnik/make_unique.hpp>
 #include <mapnik/feature.hpp>
 #include <mapnik/symbolizer.hpp>
 #include <mapnik/proj_transform.hpp>
 #include <mapnik/cairo/cairo_renderer.hpp>
-#include <mapnik/transform_path_adapter.hpp>
 // mapnik symbolizer generics
 #include <mapnik/renderer_common/process_building_symbolizer.hpp>
 
 // stl
 #include <cmath>
+#include <memory>
 
-namespace mapnik
-{
+namespace mapnik {
 
-template <typename T>
+template<typename T>
 void cairo_renderer<T>::process(building_symbolizer const& sym,
-                                  mapnik::feature_impl & feature,
-                                  proj_transform const& prj_trans)
+                                mapnik::feature_impl& feature,
+                                proj_transform const& prj_trans)
 {
-    using transform_path_type = transform_path_adapter<view_transform,vertex_adapter>;
     cairo_save_restore guard(context_);
     composite_mode_e comp_op = get<composite_mode_e, keys::comp_op>(sym, feature, common_.vars_);
     mapnik::color fill = get<color, keys::fill>(sym, feature, common_.vars_);
@@ -52,41 +49,41 @@ void cairo_renderer<T>::process(building_symbolizer const& sym,
 
     context_.set_operator(comp_op);
 
-    render_building_symbolizer(
-        feature, height,
-        [&](path_type const& faces)
-        {
-            vertex_adapter va(faces);
-            transform_path_type faces_path(common_.t_, va, prj_trans);
-            context_.set_color(fill.red()  * 0.8 / 255.0, fill.green() * 0.8 / 255.0,
-                               fill.blue() * 0.8 / 255.0, fill.alpha() * opacity / 255.0);
-            context_.add_path(faces_path);
-            context_.fill();
-        },
-        [&](path_type const& frame)
-        {
-            vertex_adapter va(frame);
-            transform_path_type path(common_.t_, va, prj_trans);
-            context_.set_color(fill.red()  * 0.8 / 255.0, fill.green() * 0.8/255.0,
-                              fill.blue() * 0.8 / 255.0, fill.alpha() * opacity / 255.0);
-            context_.set_line_width(common_.scale_factor_);
-            context_.add_path(path);
-            context_.stroke();
-        },
-        [&](path_type const& roof)
-        {
-            vertex_adapter va(roof);
-            transform_path_type roof_path(common_.t_, va, prj_trans);
-            context_.set_color(fill, opacity);
-            context_.add_path(roof_path);
-            context_.fill();
-        });
+    render_building_symbolizer::apply(
+      feature,
+      prj_trans,
+      common_.t_,
+      height,
+      [&](path_type const& faces) {
+          vertex_adapter va(faces);
+          context_.set_color(fill.red() * 0.8 / 255.0,
+                             fill.green() * 0.8 / 255.0,
+                             fill.blue() * 0.8 / 255.0,
+                             fill.alpha() * opacity / 255.0);
+          context_.add_path(va);
+          context_.fill();
+      },
+      [&](path_type const& frame) {
+          vertex_adapter va(frame);
+          context_.set_color(fill.red() * 0.8 / 255.0,
+                             fill.green() * 0.8 / 255.0,
+                             fill.blue() * 0.8 / 255.0,
+                             fill.alpha() * opacity / 255.0);
+          context_.set_line_width(common_.scale_factor_);
+          context_.set_miter_limit(common_.scale_factor_ / 2.0);
+          context_.add_path(va);
+          context_.stroke();
+      },
+      [&](render_building_symbolizer::roof_type& roof) {
+          context_.set_color(fill, opacity);
+          context_.add_path(roof);
+          context_.fill();
+      });
 }
 
-template void cairo_renderer<cairo_ptr>::process(building_symbolizer const&,
-                                                 mapnik::feature_impl &,
-                                                 proj_transform const&);
+template void
+  cairo_renderer<cairo_ptr>::process(building_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-}
+} // namespace mapnik
 
 #endif // HAVE_CAIRO
