@@ -29,15 +29,14 @@
 #include <mapnik/vertex_converters.hpp>
 #include <mapnik/vertex_processor.hpp>
 #include <mapnik/renderer_common/apply_vertex_converter.hpp>
-#include <mapnik/geometry_type.hpp>
+#include <mapnik/geometry/geometry_type.hpp>
 
-namespace mapnik
-{
+namespace mapnik {
 
-template <typename T>
+template<typename T>
 void cairo_renderer<T>::process(line_symbolizer const& sym,
-                                  mapnik::feature_impl & feature,
-                                  proj_transform const& prj_trans)
+                                mapnik::feature_impl& feature,
+                                proj_transform const& prj_trans)
 {
     composite_mode_e comp_op = get<composite_mode_e, keys::comp_op>(sym, feature, common_.vars_);
     value_bool clip = get<value_bool, keys::clip>(sym, feature, common_.vars_);
@@ -68,26 +67,31 @@ void cairo_renderer<T>::process(line_symbolizer const& sym,
 
     agg::trans_affine tr;
     auto geom_transform = get_optional<transform_type>(sym, keys::geometry_transform);
-    if (geom_transform) { evaluate_transform(tr, feature, common_.vars_, *geom_transform, common_.scale_factor_); }
+    if (geom_transform)
+    {
+        evaluate_transform(tr, feature, common_.vars_, *geom_transform, common_.scale_factor_);
+    }
 
     box2d<double> clipping_extent = common_.query_extent_;
     if (clip)
     {
-        double pad_per_pixel = static_cast<double>(common_.query_extent_.width()/common_.width_);
-        double pixels = std::ceil(std::max(width / 2.0 + std::fabs(offset),
-                                          (std::fabs(offset) * offset_converter_default_threshold)));
+        double pad_per_pixel = static_cast<double>(common_.query_extent_.width() / common_.width_);
+        double pixels = std::ceil(
+          std::max(width / 2.0 + std::fabs(offset), (std::fabs(offset) * offset_converter_default_threshold)));
         double padding = pad_per_pixel * pixels * common_.scale_factor_;
 
         clipping_extent.pad(padding);
     }
-    using vertex_converter_type =  vertex_converter<clip_line_tag,
-                                                    clip_poly_tag,
-                                                    transform_tag,
-                                                    affine_transform_tag,
-                                                    simplify_tag, smooth_tag,
-                                                    offset_transform_tag>;
+    using vertex_converter_type = vertex_converter<clip_line_tag,
+                                                   clip_poly_tag,
+                                                   transform_tag,
+                                                   affine_transform_tag,
+                                                   simplify_tag,
+                                                   smooth_tag,
+                                                   offset_transform_tag>;
 
-    vertex_converter_type converter(clipping_extent,sym,common_.t_,prj_trans,tr,feature,common_.vars_,common_.scale_factor_);
+    vertex_converter_type
+      converter(clipping_extent, sym, common_.t_, prj_trans, tr, feature, common_.vars_, common_.scale_factor_);
 
     if (clip)
     {
@@ -98,23 +102,24 @@ void cairo_renderer<T>::process(line_symbolizer const& sym,
             converter.template set<clip_line_tag>();
     }
     converter.set<transform_tag>(); // always transform
-    if (std::fabs(offset) > 0.0) converter.set<offset_transform_tag>(); // parallel offset
-    converter.set<affine_transform_tag>(); // optional affine transform
-    if (simplify_tolerance > 0.0) converter.set<simplify_tag>(); // optional simplify converter
-    if (smooth > 0.0) converter.set<smooth_tag>(); // optional smooth converter
+    if (std::fabs(offset) > 0.0)
+        converter.set<offset_transform_tag>(); // parallel offset
+    converter.set<affine_transform_tag>();     // optional affine transform
+    if (simplify_tolerance > 0.0)
+        converter.set<simplify_tag>(); // optional simplify converter
+    if (smooth > 0.0)
+        converter.set<smooth_tag>(); // optional smooth converter
     using apply_vertex_converter_type = detail::apply_vertex_converter<vertex_converter_type, cairo_context>;
     using vertex_processor_type = geometry::vertex_processor<apply_vertex_converter_type>;
     apply_vertex_converter_type apply(converter, context_);
-    mapnik::util::apply_visitor(vertex_processor_type(apply),feature.get_geometry());
+    mapnik::util::apply_visitor(vertex_processor_type(apply), feature.get_geometry());
     // stroke
     context_.set_fill_rule(CAIRO_FILL_RULE_WINDING);
     context_.stroke();
 }
 
-template void cairo_renderer<cairo_ptr>::process(line_symbolizer const&,
-                                                 mapnik::feature_impl &,
-                                                 proj_transform const&);
+template void cairo_renderer<cairo_ptr>::process(line_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-}
+} // namespace mapnik
 
 #endif // HAVE_CAIRO
