@@ -23,7 +23,6 @@
 #if defined(HAVE_CAIRO)
 
 // mapnik
-#include <mapnik/make_unique.hpp>
 #include <mapnik/feature.hpp>
 #include <mapnik/symbolizer_enumerations.hpp>
 #include <mapnik/proj_transform.hpp>
@@ -32,29 +31,30 @@
 // mapnik symbolizer generics
 #include <mapnik/renderer_common/process_raster_symbolizer.hpp>
 
-namespace mapnik
-{
+#include <memory>
 
-template <typename T>
+namespace mapnik {
+
+template<typename T>
 void cairo_renderer<T>::process(raster_symbolizer const& sym,
-                                  mapnik::feature_impl & feature,
-                                  proj_transform const& prj_trans)
+                                mapnik::feature_impl& feature,
+                                proj_transform const& prj_trans)
 {
     cairo_save_restore guard(context_);
     render_raster_symbolizer(
-        sym, feature, prj_trans, common_,
-        [&](image_rgba8 const & target, composite_mode_e comp_op, double opacity,
-            int start_x, int start_y) {
-            context_.set_operator(comp_op);
-            context_.add_image(start_x, start_y, target, opacity);
-        }
-    );
+      sym,
+      feature,
+      prj_trans,
+      common_,
+      [&](image_rgba8 const& target, composite_mode_e comp_op, double opacity, int start_x, int start_y) {
+          context_.set_operator(comp_op);
+          context_.add_image(start_x, start_y, target, opacity);
+      });
 }
 
-template void cairo_renderer<cairo_ptr>::process(raster_symbolizer const&,
-                                                 mapnik::feature_impl &,
-                                                 proj_transform const&);
+template void
+  cairo_renderer<cairo_ptr>::process(raster_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-}
+} // namespace mapnik
 
 #endif // HAVE_CAIRO
