@@ -24,21 +24,20 @@
 #include <mapnik/color.hpp>
 #include <mapnik/color_factory.hpp>
 #include <mapnik/config_error.hpp>
-#include <mapnik/css_color_grammar.hpp>
+#include <mapnik/css/css_color_grammar_x3.hpp>
 
 namespace mapnik {
 
 color parse_color(std::string const& str)
 {
     // TODO - early return for @color?
-    static const css_color_grammar<std::string::const_iterator> g;
+    auto const& grammar = mapnik::css_color_grammar::css_color;
     color c;
     std::string::const_iterator first = str.begin();
-    std::string::const_iterator last =  str.end();
-    boost::spirit::ascii::space_type space;
-    bool result = boost::spirit::qi::phrase_parse(first, last, g,
-                                                  space,
-                                                  c);
+    std::string::const_iterator last = str.end();
+    using namespace boost::spirit::x3::ascii;
+
+    bool result = boost::spirit::x3::phrase_parse(first, last, grammar, space, c);
     if (result && (first == last))
     {
         return c;
@@ -49,4 +48,4 @@ color parse_color(std::string const& str)
     }
 }
 
-}
+} // namespace mapnik
