@@ -24,16 +24,18 @@
 #include <mapnik/debug.hpp>
 #include <mapnik/datasource.hpp>
 #include <mapnik/datasource_cache.hpp>
+#include <mapnik/datasource_plugin.hpp>
 #include <mapnik/config_error.hpp>
 #include <mapnik/params.hpp>
 #include <mapnik/plugin.hpp>
 #include <mapnik/util/fs.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
 #include <boost/algorithm/string/join.hpp>
 #include <boost/algorithm/string/predicate.hpp>
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 // stl
 #include <algorithm>
@@ -49,40 +51,30 @@ extern std::vector<std::string> get_static_datasource_names();
 
 bool is_input_plugin(std::string const& filename)
 {
-    return boost::algorithm::ends_with(filename,std::string(".input"));
+    return boost::algorithm::ends_with(filename, std::string(".input"));
 }
 
-datasource_cache::datasource_cache()
-{
-    PluginInfo::init();
-}
-
-datasource_cache::~datasource_cache()
-{
-    PluginInfo::exit();
-}
+datasource_cache::datasource_cache() {}
+datasource_cache::~datasource_cache() {}
 
 datasource_ptr datasource_cache::create(parameters const& params)
 {
-    boost::optional<std::string> type = params.get<std::string>("type");
-    if (!type)
+    const auto type = params.get<std::string>("type");
+    if (!type.has_value())
     {
-        throw config_error(std::string("Could not create datasource. Required ") +
-                           "parameter 'type' is missing");
+        throw config_error(std::string("Could not create datasource. Required ") + "parameter 'type' is missing");
     }
 
-    datasource_ptr ds;
-
 #ifdef MAPNIK_STATIC_PLUGINS
     // return if it's created, raise otherwise
-    ds = create_static_datasource(params);
+    datasource_ptr ds = create_static_datasource(params);
     if (ds)
     {
         return ds;
     }
 #endif
 
-    std::map<std::string,std::shared_ptr<PluginInfo> >::iterator itr;
+    std::map<std::string, std::shared_ptr<PluginInfo>>::iterator itr;
     // add scope to ensure lock is released asap
     {
 #ifdef MAPNIK_THREADSAFE
@@ -107,25 +99,21 @@ datasource_ptr datasource_cache::create(parameters const& params)
 
     if (!itr->second->valid())
     {
-        throw std::runtime_error(std::string("Cannot load library: ") +
-                                 itr->second->get_error());
+        throw std::runtime_error(std::string("Cannot load library: ") + itr->second->get_error());
     }
 
     // http://www.mr-edd.co.uk/blog/supressing_gcc_warnings
 #ifdef __GNUC__
     __extension__
 #endif
-        create_ds create_datasource = reinterpret_cast<create_ds>(itr->second->get_symbol("create"));
+      datasource_plugin* create_datasource = reinterpret_cast<datasource_plugin*>(itr->second->get_symbol("plugin"));
 
     if (!create_datasource)
     {
-        throw std::runtime_error(std::string("Cannot load symbols: ") +
-                                 itr->second->get_error());
+        throw std::runtime_error(std::string("Cannot load symbols: ") + itr->second->get_error());
     }
 
-    ds = datasource_ptr(create_datasource(params), datasource_deleter());
-
-    return ds;
+    return create_datasource->create(params);
 }
 
 std::string datasource_cache::plugin_directories()
@@ -133,10 +121,32 @@ std::string datasource_cache::plugin_directories()
 #ifdef MAPNIK_THREADSAFE
     std::lock_guard<std::recursive_mutex> lock(instance_mutex_);
 #endif
-    return boost::algorithm::join(plugin_directories_,", ");
+    return boost::algorithm::join(plugin_directories_, ", ");
 }
 
-std::vector<std::string> datasource_cache::plugin_names()
+bool datasource_cache::plugin_registered(const std::string& plugin_name) const
+{
+#ifdef MAPNIK_STATIC_PLUGINS
+    const auto static_names = get_static_datasource_names();
+    const auto static_it = std::find(static_names.begin(), static_names.end(), plugin_name);
+    if (static_it != static_names.end())
+        return true;
+#endif
+
+#ifdef MAPNIK_THREADSAFE
+    std::lock_guard<std::recursive_mutex> lock(instance_mutex_);
+#endif
+
+    std::map<std::string, std::shared_ptr<PluginInfo>>::const_iterator itr;
+    for (itr = plugins_.begin(); itr != plugins_.end(); ++itr)
+    {
+        if (itr->second->name() == plugin_name)
+            return true;
+    }
+    return false;
+}
+
+std::vector<std::string> datasource_cache::plugin_names() const
 {
     std::vector<std::string> names;
 
@@ -148,7 +158,7 @@ std::vector<std::string> datasource_cache::plugin_names()
     std::lock_guard<std::recursive_mutex> lock(instance_mutex_);
 #endif
 
-    std::map<std::string,std::shared_ptr<PluginInfo> >::const_iterator itr;
+    std::map<std::string, std::shared_ptr<PluginInfo>>::const_iterator itr;
     for (itr = plugins_.begin(); itr != plugins_.end(); ++itr)
     {
         names.push_back(itr->first);
@@ -186,8 +196,7 @@ bool datasource_cache::register_datasources(std::string const& dir, bool recurse
             else
             {
                 std::string base_name = mapnik::util::basename(file_name);
-                if (!boost::algorithm::starts_with(base_name,".") &&
-                    mapnik::util::is_regular_file(file_name) &&
+                if (!boost::algorithm::starts_with(base_name, ".") && mapnik::util::is_regular_file(file_name) &&
                     is_input_plugin(file_name))
                 {
                     if (register_datasource(file_name))
@@ -214,27 +223,22 @@ bool datasource_cache::register_datasource(std::string const& filename)
     {
         if (!mapnik::util::exists(filename))
         {
-            MAPNIK_LOG_ERROR(datasource_cache)
-                    << "Cannot load '"
-                    << filename << "' (plugin does not exist)";
+            MAPNIK_LOG_ERROR(datasource_cache) << "Cannot load '" << filename << "' (plugin does not exist)";
             return false;
         }
-        std::shared_ptr<PluginInfo> plugin = std::make_shared<PluginInfo>(filename,"datasource_name");
+        std::shared_ptr<PluginInfo> plugin = std::make_shared<PluginInfo>(filename, "datasource_name");
         if (plugin->valid())
         {
             if (plugin->name().empty())
             {
                 MAPNIK_LOG_ERROR(datasource_cache)
-                        << "Problem loading plugin library '"
-                        << filename << "' (plugin is lacking compatible interface)";
+                  << "Problem loading plugin library '" << filename << "' (plugin is lacking compatible interface)";
             }
             else
             {
-                if (plugins_.emplace(plugin->name(),plugin).second)
+                if (plugins_.emplace(plugin->name(), plugin).second)
                 {
-                    MAPNIK_LOG_DEBUG(datasource_cache)
-                            << "datasource_cache: Registered="
-                            << plugin->name();
+                    MAPNIK_LOG_DEBUG(datasource_cache) << "datasource_cache: Registered=" << plugin->name();
                     return true;
                 }
             }
@@ -242,17 +246,16 @@ bool datasource_cache::register_datasource(std::string const& filename)
         else
         {
             MAPNIK_LOG_ERROR(datasource_cache)
-                    << "Problem loading plugin library: "
-                    << filename << " (dlopen failed - plugin likely has an unsatisfied dependency or incompatible ABI)";
+              << "Problem loading plugin library: " << filename
+              << " (dlopen failed - plugin likely has an unsatisfied dependency or incompatible ABI)";
         }
     }
     catch (std::exception const& ex)
     {
         MAPNIK_LOG_ERROR(datasource_cache)
-                << "Exception caught while loading plugin library: "
-                << filename << " (" << ex.what() << ")";
+          << "Exception caught while loading plugin library: " << filename << " (" << ex.what() << ")";
     }
     return false;
 }
 
-}
+} // namespace mapnik
