@@ -21,21 +21,17 @@
  *****************************************************************************/
 
 #include <mapnik/geometry/interior.hpp>
-#include <mapnik/geometry_envelope.hpp>
-#include <mapnik/box2d.hpp>
-#include <mapnik/geometry_centroid.hpp>
+#include <mapnik/geometry/envelope.hpp>
+#include <mapnik/geometry/box2d.hpp>
+#include <mapbox/geometry/point_arithmetic.hpp>
+#include <mapnik/geometry/centroid.hpp>
 
 #include <algorithm>
 #include <cmath>
-#include <iostream>
 #include <queue>
 
-#pragma GCC diagnostic push
-#include <mapnik/warning_ignore.hpp>
-#include <boost/optional.hpp>
-#pragma GCC diagnostic pop
-
-namespace mapnik { namespace geometry {
+namespace mapnik {
+namespace geometry {
 
 // Interior algorithm is realized as a modification of Polylabel algorithm
 // from https://github.com/mapbox/polylabel.
@@ -45,25 +41,25 @@ namespace mapnik { namespace geometry {
 namespace detail {
 
 // get squared distance from a point to a segment
-template <class T>
-T segment_dist_sq(const point<T>& p,
-                  const point<T>& a,
-                  const point<T>& b)
+template<class T>
+T segment_dist_sq(const point<T>& p, const point<T>& a, const point<T>& b)
 {
     auto x = a.x;
     auto y = a.y;
     auto dx = b.x - x;
     auto dy = b.y - y;
 
-    if (dx != 0 || dy != 0) {
-
+    if (dx != 0 || dy != 0)
+    {
         auto t = ((p.x - x) * dx + (p.y - y) * dy) / (dx * dx + dy * dy);
 
-        if (t > 1) {
+        if (t > 1)
+        {
             x = b.x;
             y = b.y;
-
-        } else if (t > 0) {
+        }
+        else if (t > 0)
+        {
             x += dx * t;
             y += dy * t;
         }
@@ -75,54 +71,45 @@ T segment_dist_sq(const point<T>& p,
     return dx * dx + dy * dy;
 }
 
-template <class T>
-void point_to_ring_dist(point<T> const& point, linear_ring<T> const& ring,
-                        bool & inside, double & min_dist_sq)
-{
-    for (std::size_t i = 0, len = ring.size(), j = len - 1; i < len; j = i++)
-    {
-        const auto& a = ring[i];
-        const auto& b = ring[j];
-
-        if ((a.y > point.y) != (b.y > point.y) &&
-            (point.x < (b.x - a.x) * (point.y - a.y) / (b.y - a.y) + a.x)) inside = !inside;
-
-        min_dist_sq = std::min(min_dist_sq, segment_dist_sq(point, a, b));
-    }
-}
-
 // signed distance from point to polygon outline (negative if point is outside)
-template <class T>
-double point_to_polygon_dist(const point<T>& point, const polygon<T>& polygon)
+template<class T>
+auto point_to_polygon_dist(const point<T>& point, const polygon<T>& polygon)
 {
     bool inside = false;
-    double min_dist_sq = std::numeric_limits<double>::infinity();
+    auto min_dist_sq = std::numeric_limits<double>::infinity();
 
-    point_to_ring_dist(point, polygon.exterior_ring, inside, min_dist_sq);
-
-    for (const auto& ring : polygon.interior_rings)
+    for (const auto& ring : polygon)
     {
-        point_to_ring_dist(point, ring, inside, min_dist_sq);
+        for (std::size_t i = 0, len = ring.size(), j = len - 1; i < len; j = i++)
+        {
+            const auto& a = ring[i];
+            const auto& b = ring[j];
+
+            if ((a.y > point.y) != (b.y > point.y) && (point.x < (b.x - a.x) * (point.y - a.y) / (b.y - a.y) + a.x))
+                inside = !inside;
+
+            min_dist_sq = std::min(min_dist_sq, segment_dist_sq(point, a, b));
+        }
     }
 
     return (inside ? 1 : -1) * std::sqrt(min_dist_sq);
 }
 
-template <class T>
+template<class T>
 struct fitness_functor
 {
     fitness_functor(point<T> const& centroid, point<T> const& polygon_size)
-        : centroid(centroid),
-          max_size(std::max(polygon_size.x, polygon_size.y))
-        {}
+        : centroid(centroid)
+        , max_size(std::max(polygon_size.x, polygon_size.y))
+    {}
 
-    T operator()(point<T> const& cell_center, T distance_polygon) const
+    T operator()(const point<T>& cell_center, T distance_polygon) const
     {
         if (distance_polygon <= 0)
         {
             return distance_polygon;
         }
-        point<T> d(cell_center.x - centroid.x, cell_center.y - centroid.y);
+        point<T> d = cell_center - centroid;
         double distance_centroid = std::sqrt(d.x * d.x + d.y * d.y);
         return distance_polygon * (1 - distance_centroid / max_size);
     }
@@ -131,38 +118,35 @@ struct fitness_functor
     T max_size;
 };
 
-template <class T>
+template<class T>
 struct cell
 {
-    template <class FitnessFunc>
-    cell(const point<T>& c_, T h_,
-         const polygon<T>& polygon,
-         const FitnessFunc& ff)
-        : c(c_),
-          h(h_),
-          d(point_to_polygon_dist(c, polygon)),
-          fitness(ff(c, d)),
-          max_fitness(ff(c, d + h * std::sqrt(2)))
-        {}
+    template<class FitnessFunc>
+    cell(const point<T>& c_, T h_, const polygon<T>& polygon, const FitnessFunc& ff)
+        : c(c_)
+        , h(h_)
+        , d(point_to_polygon_dist(c, polygon))
+        , fitness(ff(c, d))
+        , max_fitness(ff(c, d + h * std::sqrt(2)))
+    {}
 
-    point<T> c; // cell center
-    T h; // half the cell size
-    T d; // distance from cell center to polygon
-    T fitness; // fitness of the cell center
+    point<T> c;    // cell center
+    T h;           // half the cell size
+    T d;           // distance from cell center to polygon
+    T fitness;     // fitness of the cell center
     T max_fitness; // a "potential" of the cell calculated from max distance to polygon within the cell
 };
 
-template <class T>
-point<T> polylabel(polygon<T> const& polygon, box2d<T> const& bbox , T precision = 1)
+template<class T>
+point<T> polylabel(polygon<T> const& polygon, box2d<T> const& bbox, T precision = 1)
 {
-    const point<T> size { bbox.width(), bbox.height() };
+    const point<T> size{bbox.width(), bbox.height()};
 
     const T cell_size = std::min(size.x, size.y);
     T h = cell_size / 2;
 
     // a priority queue of cells in order of their "potential" (max distance to polygon)
-    auto compare_func = [] (const cell<T>& a, const cell<T>& b)
-    {
+    auto compare_func = [](const cell<T>& a, const cell<T>& b) {
         return a.max_fitness < b.max_fitness;
     };
     using Queue = std::priority_queue<cell<T>, std::vector<cell<T>>, decltype(compare_func)>;
@@ -170,14 +154,14 @@ point<T> polylabel(polygon<T> const& polygon, box2d<T> const& bbox , T precision
 
     if (cell_size == 0)
     {
-        return { bbox.minx(), bbox.miny() };
+        return {bbox.minx(), bbox.miny()};
     }
 
     point<T> centroid;
     if (!mapnik::geometry::centroid(polygon, centroid))
     {
         auto center = bbox.center();
-        return { center.x, center.y };
+        return {center.x, center.y};
     }
 
     fitness_functor<T> fitness_func(centroid, size);
@@ -207,7 +191,8 @@ point<T> polylabel(polygon<T> const& polygon, box2d<T> const& bbox , T precision
         }
 
         // do not drill down further if there's no chance of a better solution
-        if (current_cell.max_fitness - best_cell.fitness <= precision) continue;
+        if (current_cell.max_fitness - best_cell.fitness <= precision)
+            continue;
 
         // split the cell into four cells
         h = current_cell.h / 2;
@@ -222,15 +207,15 @@ point<T> polylabel(polygon<T> const& polygon, box2d<T> const& bbox , T precision
 
 } // namespace detail
 
-template <class T>
-bool interior(polygon<T> const& polygon, double scale_factor, point<T> & pt)
+template<class T>
+bool interior(polygon<T> const& polygon, double scale_factor, point<T>& pt)
 {
-    if (polygon.exterior_ring.empty())
+    if (polygon.empty() || polygon.front().empty())
     {
         return false;
     }
 
-    const box2d<T> bbox = envelope(polygon.exterior_ring);
+    const box2d<T> bbox = envelope(polygon.at(0));
 
     // Let the precision be 1% of the polygon size to be independent to map scale.
     double precision = (std::max(bbox.width(), bbox.height()) / 100.0) * scale_factor;
@@ -239,8 +224,7 @@ bool interior(polygon<T> const& polygon, double scale_factor, point<T> & pt)
     return true;
 }
 
-template
-bool interior(polygon<double> const& polygon, double scale_factor, point<double> & pt);
-
-} }
+template MAPNIK_DECL bool interior(polygon<double> const& polygon, double scale_factor, point<double>& pt);
 
+} // namespace geometry
+} // namespace mapnik
