@@ -23,43 +23,45 @@
 #include <mapnik/gradient.hpp>
 #include <mapnik/enumeration.hpp>
 
-namespace mapnik
-{
+namespace mapnik {
 
 gradient::gradient()
-: transform_(),
-  x1_(0),
-  y1_(0),
-  x2_(0),
-  y2_(0),
-  r_(0),
-  stops_(),
-  units_(OBJECT_BOUNDING_BOX),
-  gradient_type_(NO_GRADIENT) {}
+    : transform_()
+    , x1_(0)
+    , y1_(0)
+    , x2_(0)
+    , y2_(0)
+    , r_(0)
+    , stops_()
+    , units_(OBJECT_BOUNDING_BOX)
+    , gradient_type_(NO_GRADIENT)
+{}
 
 gradient::gradient(gradient const& other)
-    : transform_(other.transform_),
-      x1_(other.x1_),
-      y1_(other.y1_),
-      x2_(other.x2_),
-      y2_(other.y2_),
-      r_(other.r_),
-      stops_(other.stops_),
-      units_(other.units_),
-      gradient_type_(other.gradient_type_) {}
+    : transform_(other.transform_)
+    , x1_(other.x1_)
+    , y1_(other.y1_)
+    , x2_(other.x2_)
+    , y2_(other.y2_)
+    , r_(other.r_)
+    , stops_(other.stops_)
+    , units_(other.units_)
+    , gradient_type_(other.gradient_type_)
+{}
 
-gradient::gradient(gradient && other)
-    : transform_(std::move(other.transform_)),
-      x1_(std::move(other.x1_)),
-      y1_(std::move(other.y1_)),
-      x2_(std::move(other.x2_)),
-      y2_(std::move(other.y2_)),
-      r_(std::move(other.r_)),
-      stops_(std::move(other.stops_)),
-      units_(std::move(other.units_)),
-      gradient_type_(std::move(other.gradient_type_)) {}
+gradient::gradient(gradient&& other)
+    : transform_(std::move(other.transform_))
+    , x1_(std::move(other.x1_))
+    , y1_(std::move(other.y1_))
+    , x2_(std::move(other.x2_))
+    , y2_(std::move(other.y2_))
+    , r_(std::move(other.r_))
+    , stops_(std::move(other.stops_))
+    , units_(std::move(other.units_))
+    , gradient_type_(std::move(other.gradient_type_))
+{}
 
-gradient & gradient::operator=(gradient rhs)
+gradient& gradient::operator=(gradient rhs)
 {
     swap(rhs);
     return *this;
@@ -67,20 +69,14 @@ gradient & gradient::operator=(gradient rhs)
 
 bool gradient::operator==(gradient const& other) const
 {
-    return transform_ == other.transform_ &&
-        x1_ == other.x1_ &&
-        y1_ == other.y1_ &&
-        x2_ == other.x2_ &&
-        y2_ == other.y2_ &&
-        r_  == other.r_  &&
-        std::equal(stops_.begin(),stops_.end(), other.stops_.begin()),
-        units_ == other.units_ &&
-        gradient_type_ == other.gradient_type_;
+    return transform_ == other.transform_ && x1_ == other.x1_ && y1_ == other.y1_ && x2_ == other.x2_ &&
+           y2_ == other.y2_ && r_ == other.r_ && std::equal(stops_.begin(), stops_.end(), other.stops_.begin()) &&
+           units_ == other.units_ && gradient_type_ == other.gradient_type_;
 }
 
 void gradient::set_gradient_type(gradient_e grad)
 {
-    gradient_type_=grad;
+    gradient_type_ = grad;
 }
 
 gradient_e gradient::get_gradient_type() const
@@ -106,9 +102,9 @@ gradient_unit_e gradient::get_units() const
     return units_;
 }
 
-void gradient::add_stop(double offset,mapnik::color const& c)
+void gradient::add_stop(double offset, mapnik::color const& c)
 {
-    stops_.push_back(mapnik::stop_pair(offset,c));
+    stops_.push_back(mapnik::stop_pair(offset, c));
 }
 
 bool gradient::has_stop() const
@@ -142,12 +138,12 @@ void gradient::set_control_points(double x1, double y1, double x2, double y2, do
     y2_ = y2;
     r_ = r;
 }
-void gradient::get_control_points(double &x1, double &y1, double &x2, double &y2, double &r) const
+void gradient::get_control_points(double& x1, double& y1, double& x2, double& y2, double& r) const
 {
-    get_control_points(x1,y1,x2,y2);
-    r=r_;
+    get_control_points(x1, y1, x2, y2);
+    r = r_;
 }
-void gradient::get_control_points(double &x1, double &y1, double &x2, double &y2) const
+void gradient::get_control_points(double& x1, double& y1, double& x2, double& y2) const
 {
     x1 = x1_;
     y1 = y1_;
@@ -155,4 +151,4 @@ void gradient::get_control_points(double &x1, double &y1, double &x2, double &y2
     y2 = y2_;
 }
 
-}
+} // namespace mapnik
