@@ -37,10 +37,11 @@
 #include <mapnik/svg/svg_path_attributes.hpp>
 #include <mapnik/renderer_common/render_group_symbolizer.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_trans_affine.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 namespace mapnik {
 
@@ -50,46 +51,42 @@ namespace mapnik {
  * to render it, and the boxes themselves should already be
  * in the detector from the placement_finder.
  */
-template <typename T0>
+template<typename T0>
 struct thunk_renderer : render_thunk_list_dispatch
 {
     using renderer_type = grid_renderer<T0>;
     using buffer_type = typename renderer_type::buffer_type;
     using text_renderer_type = grid_text_renderer<buffer_type>;
 
-    thunk_renderer(renderer_type &ren,
-                   grid_rasterizer &ras,
-                   buffer_type &pixmap,
-                   renderer_common &common,
-                   feature_impl &feature)
-        : ren_(ren), ras_(ras), pixmap_(pixmap),
-          common_(common), feature_(feature),
-          tex_(pixmap, src_over, common.scale_factor_)
+    thunk_renderer(renderer_type& ren,
+                   grid_rasterizer& ras,
+                   buffer_type& pixmap,
+                   renderer_common& common,
+                   feature_impl& feature)
+        : ren_(ren)
+        , ras_(ras)
+        , pixmap_(pixmap)
+        , common_(common)
+        , feature_(feature)
+        , tex_(pixmap, src_over, common.scale_factor_)
     {}
 
     virtual void operator()(vector_marker_render_thunk const& thunk)
     {
         using buf_type = grid_rendering_buffer;
         using pixfmt_type = typename grid_renderer_base_type::pixfmt_type;
-        using marker_renderer_type = agg::renderer_scanline_bin_solid<grid_renderer_base_type>;
-
-        using namespace mapnik::svg;
-        using svg_renderer_type = svg_renderer_agg<svg_path_adapter,
-                                                   svg_attribute_type,
-                                                   marker_renderer_type,
-                                                   pixfmt_type>;
-
+        using renderer_type = agg::renderer_scanline_bin_solid<grid_renderer_base_type>;
+        using svg_renderer_type = svg::renderer_agg<svg_path_adapter, svg_attribute_type, renderer_type, pixfmt_type>;
         buf_type render_buf(pixmap_.raw_data(), common_.width_, common_.height_, common_.width_);
         ras_.reset();
         pixfmt_type pixf(render_buf);
         grid_renderer_base_type renb(pixf);
-        marker_renderer_type ren(renb);
-        vertex_stl_adapter<svg_path_storage> stl_storage(thunk.src_->source());
+        renderer_type ren(renb);
+        svg::vertex_stl_adapter<svg::svg_path_storage> stl_storage(thunk.src_->source());
         svg_path_adapter svg_path(stl_storage);
-        svg_renderer_type svg_renderer(svg_path, thunk.attrs_);
+        svg_renderer_type svg_renderer(svg_path, thunk.group_attrs_);
         agg::trans_affine offset_tr = thunk.tr_;
         offset_tr.translate(offset_.x, offset_.y);
-        //render_vector_marker(svg_renderer, *ras_ptr_, renb, thunk.src_->bounding_box(), offset_tr, thunk.opacity_, thunk.snap_to_pixels_);
         agg::scanline_bin sl;
         svg_renderer.render_id(ras_, sl, renb, feature_.id(), offset_tr, thunk.opacity_, thunk.src_->bounding_box());
         pixmap_.add_feature(feature_);
@@ -99,19 +96,19 @@ struct thunk_renderer : render_thunk_list_dispatch
     {
         using buf_type = grid_rendering_buffer;
         using pixfmt_type = typename grid_renderer_base_type::pixfmt_type;
-        using marker_renderer_type = agg::renderer_scanline_bin_solid<grid_renderer_base_type>;
+        using renderer_type = agg::renderer_scanline_bin_solid<grid_renderer_base_type>;
         buf_type render_buf(pixmap_.raw_data(), common_.width_, common_.height_, common_.width_);
         ras_.reset();
         pixfmt_type pixf(render_buf);
         grid_renderer_base_type renb(pixf);
-        marker_renderer_type ren(renb);
+        renderer_type ren(renb);
         agg::trans_affine offset_tr = thunk.tr_;
         offset_tr.translate(offset_.x, offset_.y);
         render_raster_marker(ren, ras_, thunk.src_, feature_, offset_tr, thunk.opacity_);
         pixmap_.add_feature(feature_);
     }
 
-    virtual void operator()(text_render_thunk const &thunk)
+    virtual void operator()(text_render_thunk const& thunk)
     {
         tex_.set_comp_op(thunk.comp_op_);
 
@@ -127,7 +124,8 @@ struct thunk_renderer : render_thunk_list_dispatch
                                    glyphs->marker_pos(),
                                    *mark->marker_,
                                    mark->transform_,
-                                   thunk.opacity_, thunk.comp_op_);
+                                   thunk.opacity_,
+                                   thunk.comp_op_);
             }
             tex_.render(*glyphs, feature_id);
         }
@@ -135,31 +133,27 @@ struct thunk_renderer : render_thunk_list_dispatch
         pixmap_.add_feature(feature_);
     }
 
-private:
-    renderer_type &ren_;
-    grid_rasterizer & ras_;
-    buffer_type &pixmap_;
-    renderer_common &common_;
-    feature_impl &feature_;
+  private:
+    renderer_type& ren_;
+    grid_rasterizer& ras_;
+    buffer_type& pixmap_;
+    renderer_common& common_;
+    feature_impl& feature_;
     text_renderer_type tex_;
 };
 
-template <typename T>
-void  grid_renderer<T>::process(group_symbolizer const& sym,
-                                mapnik::feature_impl & feature,
-                                proj_transform const& prj_trans)
+template<typename T>
+void grid_renderer<T>::process(group_symbolizer const& sym,
+                               mapnik::feature_impl& feature,
+                               proj_transform const& prj_trans)
 {
     thunk_renderer<T> ren(*this, *ras_ptr, pixmap_, common_, feature);
 
-    render_group_symbolizer(
-        sym, feature, common_.vars_, prj_trans, common_.query_extent_, common_,
-        ren);
+    render_group_symbolizer(sym, feature, common_.vars_, prj_trans, common_.query_extent_, common_, ren);
 }
 
-template void grid_renderer<grid>::process(group_symbolizer const&,
-                                           mapnik::feature_impl &,
-                                           proj_transform const&);
+template void grid_renderer<grid>::process(group_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-}
+} // namespace mapnik
 
 #endif
