@@ -36,40 +36,42 @@
 #include <mapnik/parse_path.hpp>
 #include <mapnik/renderer_common/apply_vertex_converter.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_rasterizer_scanline_aa.h"
 #include "agg_renderer_scanline.h"
 #include "agg_scanline_bin.h"
-#include "agg_conv_stroke.h"
-#include "agg_conv_dash.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 // stl
 #include <string>
 
 namespace mapnik {
 
-template <typename T>
+template<typename T>
 void grid_renderer<T>::process(line_pattern_symbolizer const& sym,
-                               mapnik::feature_impl & feature,
+                               mapnik::feature_impl& feature,
                                proj_transform const& prj_trans)
 {
-    std::string filename = get<std::string, keys::file>(sym, feature, common_.vars_);
-    if (filename.empty()) return;
-    std::shared_ptr<mapnik::marker const> mark = marker_cache::instance().find(filename, true);
-    if (mark->is<mapnik::marker_null>()) return;
+    const std::string filename = get<std::string, keys::file>(sym, feature, common_.vars_);
+    if (filename.empty())
+        return;
+    const auto mark = marker_cache::instance().find(filename, true);
+    if (mark->is<mapnik::marker_null>())
+        return;
 
     if (!mark->is<mapnik::marker_rgba8>())
     {
-        MAPNIK_LOG_DEBUG(agg_renderer) << "agg_renderer: Only images (not '" << filename << "') are supported in the line_pattern_symbolizer";
+        MAPNIK_LOG_DEBUG(agg_renderer) << "agg_renderer: Only images (not '" << filename
+                                       << "') are supported in the line_pattern_symbolizer";
         return;
     }
 
-    value_bool clip = get<value_bool, keys::clip>(sym, feature, common_.vars_);
-    value_double offset = get<value_double, keys::offset>(sym, feature, common_.vars_);
-    value_double simplify_tolerance = get<value_double, keys::simplify_tolerance>(sym, feature, common_.vars_);
-    value_double smooth = get<value_double, keys::smooth>(sym, feature, common_.vars_);
+    const value_bool clip = get<value_bool, keys::clip>(sym, feature, common_.vars_);
+    const value_double offset = get<value_double, keys::offset>(sym, feature, common_.vars_);
+    const value_double simplify_tolerance = get<value_double, keys::simplify_tolerance>(sym, feature, common_.vars_);
+    const value_double smooth = get<value_double, keys::smooth>(sym, feature, common_.vars_);
 
     using pixfmt_type = typename grid_renderer_base_type::pixfmt_type;
     using color_type = typename grid_renderer_base_type::pixfmt_type::color_type;
@@ -86,11 +88,12 @@ void grid_renderer<T>::process(line_pattern_symbolizer const& sym,
     ras_ptr->reset();
 
     line_pattern_enum pattern = get<line_pattern_enum, keys::line_pattern>(sym, feature, common_.vars_);
-    std::size_t stroke_width = (pattern == LINE_PATTERN_WARP) ? mark->width() :
-        get<value_double, keys::stroke_width>(sym, feature, common_.vars_);
+    const std::size_t stroke_width = (pattern == line_pattern_enum::LINE_PATTERN_WARP)
+                                       ? mark->width()
+                                       : get<value_double, keys::stroke_width>(sym, feature, common_.vars_);
 
     agg::trans_affine tr;
-    auto transform = get_optional<transform_type>(sym, keys::geometry_transform);
+    const auto transform = get_optional<transform_type>(sym, keys::geometry_transform);
     if (transform)
     {
         evaluate_transform(tr, feature, common_.vars_, *transform, common_.scale_factor_);
@@ -99,10 +102,10 @@ void grid_renderer<T>::process(line_pattern_symbolizer const& sym,
     box2d<double> clipping_extent = common_.query_extent_;
     if (clip)
     {
-        double pad_per_pixel = static_cast<double>(common_.query_extent_.width()/common_.width_);
-        double pixels = std::ceil(std::max(stroke_width / 2.0 + std::fabs(offset),
-                                          (std::fabs(offset) * offset_converter_default_threshold)));
-        double padding = pad_per_pixel * pixels * common_.scale_factor_;
+        const double pad_per_pixel = static_cast<double>(common_.query_extent_.width() / common_.width_);
+        const double pixels = std::ceil(
+          std::max(stroke_width / 2.0 + std::fabs(offset), (std::fabs(offset) * offset_converter_default_threshold)));
+        const double padding = pad_per_pixel * pixels * common_.scale_factor_;
 
         clipping_extent.pad(padding);
     }
@@ -114,26 +117,34 @@ void grid_renderer<T>::process(line_pattern_symbolizer const& sym,
     // TODO: really should pass the offset to the fake line too, but
     // this wasn't present in the previous version and makes the test
     // fail - in this case, probably the test should be updated.
-    //put<value_double>(line, keys::offset, value_double(offset));
+    // put<value_double>(line, keys::offset, value_double(offset));
     put<value_double>(line, keys::simplify_tolerance, value_double(simplify_tolerance));
     put<value_double>(line, keys::smooth, value_double(smooth));
 
-    using vertex_converter_type = vertex_converter<clip_line_tag, transform_tag,
+    using vertex_converter_type = vertex_converter<clip_line_tag,
+                                                   transform_tag,
                                                    affine_transform_tag,
-                                                   simplify_tag,smooth_tag,
-                                                   offset_transform_tag,stroke_tag>;
-    vertex_converter_type converter(clipping_extent,line,common_.t_,prj_trans,tr,feature,common_.vars_,common_.scale_factor_);
-    if (clip) converter.set<clip_line_tag>();
+                                                   simplify_tag,
+                                                   smooth_tag,
+                                                   offset_transform_tag,
+                                                   stroke_tag>;
+    vertex_converter_type
+      converter(clipping_extent, line, common_.t_, prj_trans, tr, feature, common_.vars_, common_.scale_factor_);
+    if (clip)
+        converter.set<clip_line_tag>();
     converter.set<transform_tag>(); // always transform
-    if (std::fabs(offset) > 0.0) converter.set<offset_transform_tag>(); // parallel offset
-    converter.set<affine_transform_tag>(); // optional affine transform
-    if (simplify_tolerance > 0.0) converter.set<simplify_tag>(); // optional simplify converter
-    if (smooth > 0.0) converter.set<smooth_tag>(); // optional smooth converter
-    converter.set<stroke_tag>(); //always stroke
-    using apply_vertex_converter_type = detail::apply_vertex_converter<vertex_converter_type,grid_rasterizer>;
+    if (std::fabs(offset) > 0.0)
+        converter.set<offset_transform_tag>(); // parallel offset
+    converter.set<affine_transform_tag>();     // optional affine transform
+    if (simplify_tolerance > 0.0)
+        converter.set<simplify_tag>(); // optional simplify converter
+    if (smooth > 0.0)
+        converter.set<smooth_tag>(); // optional smooth converter
+    converter.set<stroke_tag>();     // always stroke
+    using apply_vertex_converter_type = detail::apply_vertex_converter<vertex_converter_type, grid_rasterizer>;
     using vertex_processor_type = geometry::vertex_processor<apply_vertex_converter_type>;
     apply_vertex_converter_type apply(converter, *ras_ptr);
-    mapnik::util::apply_visitor(vertex_processor_type(apply),feature.get_geometry());
+    mapnik::util::apply_visitor(vertex_processor_type(apply), feature.get_geometry());
 
     // render id
     ren.color(color_type(feature.id()));
@@ -141,14 +152,11 @@ void grid_renderer<T>::process(line_pattern_symbolizer const& sym,
 
     // add feature properties to grid cache
     pixmap_.add_feature(feature);
-
 }
 
+template void
+  grid_renderer<grid>::process(line_pattern_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-template void grid_renderer<grid>::process(line_pattern_symbolizer const&,
-                                           mapnik::feature_impl &,
-                                           proj_transform const&);
-
-}
+} // namespace mapnik
 
 #endif
