@@ -36,12 +36,13 @@
 #include <mapnik/parse_path.hpp>
 #include <mapnik/renderer_common/apply_vertex_converter.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_rasterizer_scanline_aa.h"
 #include "agg_renderer_scanline.h"
 #include "agg_scanline_bin.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 // stl
 #include <string>
@@ -49,19 +50,22 @@
 
 namespace mapnik {
 
-template <typename T>
+template<typename T>
 void grid_renderer<T>::process(polygon_pattern_symbolizer const& sym,
-                               mapnik::feature_impl & feature,
+                               mapnik::feature_impl& feature,
                                proj_transform const& prj_trans)
 {
     std::string filename = get<std::string, keys::file>(sym, feature, common_.vars_);
-    if (filename.empty()) return;
+    if (filename.empty())
+        return;
     std::shared_ptr<mapnik::marker const> mark = marker_cache::instance().find(filename, true);
-    if (mark->is<mapnik::marker_null>()) return;
+    if (mark->is<mapnik::marker_null>())
+        return;
 
     if (!mark->is<mapnik::marker_rgba8>())
     {
-        MAPNIK_LOG_DEBUG(agg_renderer) << "agg_renderer: Only images (not '" << filename << "') are supported in the line_pattern_symbolizer";
+        MAPNIK_LOG_DEBUG(agg_renderer) << "agg_renderer: Only images (not '" << filename
+                                       << "') are supported in the line_pattern_symbolizer";
         return;
     }
 
@@ -78,24 +82,25 @@ void grid_renderer<T>::process(polygon_pattern_symbolizer const& sym,
         evaluate_transform(tr, feature, common_.vars_, *transform, common_.scale_factor_);
     }
 
-    using vertex_converter_type = vertex_converter<clip_poly_tag,
-                                                   transform_tag,
-                                                   affine_transform_tag,
-                                                   simplify_tag,
-                                                   smooth_tag>;
+    using vertex_converter_type =
+      vertex_converter<clip_poly_tag, transform_tag, affine_transform_tag, simplify_tag, smooth_tag>;
 
-    vertex_converter_type converter(common_.query_extent_,sym,common_.t_,prj_trans,tr,feature,common_.vars_,common_.scale_factor_);
+    vertex_converter_type
+      converter(common_.query_extent_, sym, common_.t_, prj_trans, tr, feature, common_.vars_, common_.scale_factor_);
 
-    if (prj_trans.equal() && clip) converter.set<clip_poly_tag>();
-    converter.set<transform_tag>(); //always transform
+    if (prj_trans.equal() && clip)
+        converter.set<clip_poly_tag>();
+    converter.set<transform_tag>(); // always transform
     converter.set<affine_transform_tag>();
-    if (simplify_tolerance > 0.0) converter.set<simplify_tag>(); // optional simplify converter
-    if (smooth > 0.0) converter.set<smooth_tag>(); // optional smooth converter
+    if (simplify_tolerance > 0.0)
+        converter.set<simplify_tag>(); // optional simplify converter
+    if (smooth > 0.0)
+        converter.set<smooth_tag>(); // optional smooth converter
 
     using apply_vertex_converter_type = detail::apply_vertex_converter<vertex_converter_type, grid_rasterizer>;
     using vertex_processor_type = geometry::vertex_processor<apply_vertex_converter_type>;
     apply_vertex_converter_type apply(converter, *ras_ptr);
-    mapnik::util::apply_visitor(vertex_processor_type(apply),feature.get_geometry());
+    mapnik::util::apply_visitor(vertex_processor_type(apply), feature.get_geometry());
 
     using pixfmt_type = typename grid_renderer_base_type::pixfmt_type;
     using color_type = typename grid_renderer_base_type::pixfmt_type::color_type;
@@ -117,11 +122,9 @@ void grid_renderer<T>::process(polygon_pattern_symbolizer const& sym,
     pixmap_.add_feature(feature);
 }
 
+template void
+  grid_renderer<grid>::process(polygon_pattern_symbolizer const&, mapnik::feature_impl&, proj_transform const&);
 
-template void grid_renderer<grid>::process(polygon_pattern_symbolizer const&,
-                                           mapnik::feature_impl &,
-                                           proj_transform const&);
-
-}
+} // namespace mapnik
 
 #endif
