@@ -21,14 +21,15 @@
  *****************************************************************************/
 // mapnik
 #include <mapnik/renderer_common/render_pattern.hpp>
-#include <mapnik/box2d.hpp>
+#include <mapnik/geometry/box2d.hpp>
 #include <mapnik/marker.hpp>
 #include <mapnik/svg/svg_converter.hpp>
 #include <mapnik/svg/svg_renderer_agg.hpp>
 #include <mapnik/svg/svg_path_adapter.hpp>
 #include <mapnik/agg_rasterizer.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore_agg.hpp>
 #include "agg_rendering_buffer.h"
 #include "agg_pixfmt_rgba.h"
@@ -36,24 +37,28 @@
 #include "agg_color_rgba.h"
 #include "agg_color_gray.h"
 #include "agg_scanline_u.h"
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 namespace mapnik {
 
-template <>
+template<>
 void render_pattern<image_rgba8>(marker_svg const& marker,
                                  agg::trans_affine const& tr,
                                  double opacity,
-                                 image_rgba8 & image)
+                                 image_rgba8& image)
 {
-    using pixfmt = agg::pixfmt_rgba32_pre;
+    using color_type = agg::rgba8;
+    using order_type = agg::order_rgba;
+    using blender_type = agg::comp_op_adaptor_rgba_pre<color_type, order_type>; // comp blender
+    using buf_type = agg::rendering_buffer;
+    using pixfmt = agg::pixfmt_custom_blend_rgba<blender_type, buf_type>;
     using renderer_base = agg::renderer_base<pixfmt>;
     using renderer_solid = agg::renderer_scanline_aa_solid<renderer_base>;
-    agg::scanline_u8 sl;
 
+    agg::scanline_u8 sl;
     mapnik::box2d<double> const& bbox = marker.bounding_box() * tr;
-    mapnik::coord<double,2> c = bbox.center();
-    agg::trans_affine mtx = agg::trans_affine_translation(-c.x,-c.y);
+    mapnik::coord<double, 2> c = bbox.center();
+    agg::trans_affine mtx = agg::trans_affine_translation(-c.x, -c.y);
     mtx.translate(0.5 * bbox.width(), 0.5 * bbox.height());
     mtx = tr * mtx;
 
@@ -63,12 +68,10 @@ void render_pattern<image_rgba8>(marker_svg const& marker,
 
     svg::vertex_stl_adapter<svg::svg_path_storage> stl_storage(marker.get_data()->source());
     svg_path_adapter svg_path(stl_storage);
-    svg::svg_renderer_agg<svg_path_adapter,
-                          svg_attribute_type,
-                          renderer_solid,
-                          pixfmt> svg_renderer(svg_path, marker.get_data()->attributes());
+    svg::renderer_agg<svg_path_adapter, svg_attribute_type, renderer_solid, pixfmt> svg_renderer(
+      svg_path,
+      marker.get_data()->svg_group());
     rasterizer ras;
-
     svg_renderer.render(ras, sl, renb, mtx, opacity, bbox);
 }
 
