@@ -28,46 +28,47 @@
 #include <limits>
 #include <memory>
 
-namespace mapnik
-{
+namespace mapnik {
 
 rule::rule()
-    : name_(),
-      min_scale_(0),
-      max_scale_(std::numeric_limits<double>::infinity()),
-      syms_(),
-      filter_(std::make_shared<expr_node>(true)),
-      else_filter_(false),
-      also_filter_(false) {}
+    : name_()
+    , min_scale_(0)
+    , max_scale_(std::numeric_limits<double>::infinity())
+    , syms_()
+    , filter_(std::make_shared<expr_node>(true))
+    , else_filter_(false)
+    , also_filter_(false)
+{}
 
-rule::rule(std::string const& name,
-     double min_scale_denominator,
-     double max_scale_denominator)
-    : name_(name),
-      min_scale_(min_scale_denominator),
-      max_scale_(max_scale_denominator),
-      syms_(),
-      filter_(std::make_shared<mapnik::expr_node>(true)),
-      else_filter_(false),
-      also_filter_(false)  {}
+rule::rule(std::string const& name, double min_scale_denominator, double max_scale_denominator)
+    : name_(name)
+    , min_scale_(min_scale_denominator)
+    , max_scale_(max_scale_denominator)
+    , syms_()
+    , filter_(std::make_shared<mapnik::expr_node>(true))
+    , else_filter_(false)
+    , also_filter_(false)
+{}
 
 rule::rule(rule const& rhs)
-    : name_(rhs.name_),
-      min_scale_(rhs.min_scale_),
-      max_scale_(rhs.max_scale_),
-      syms_(rhs.syms_),
-      filter_(std::make_shared<expr_node>(*rhs.filter_)),
-      else_filter_(rhs.else_filter_),
-      also_filter_(rhs.also_filter_) {}
+    : name_(rhs.name_)
+    , min_scale_(rhs.min_scale_)
+    , max_scale_(rhs.max_scale_)
+    , syms_(rhs.syms_)
+    , filter_(std::make_shared<expr_node>(*rhs.filter_))
+    , else_filter_(rhs.else_filter_)
+    , also_filter_(rhs.also_filter_)
+{}
 
-rule::rule(rule && rhs)
-    : name_(std::move(rhs.name_)),
-      min_scale_(std::move(rhs.min_scale_)),
-      max_scale_(std::move(rhs.max_scale_)),
-      syms_(std::move(rhs.syms_)),
-      filter_(std::move(rhs.filter_)),
-      else_filter_(std::move(rhs.else_filter_)),
-      also_filter_(std::move(rhs.also_filter_)) {}
+rule::rule(rule&& rhs)
+    : name_(std::move(rhs.name_))
+    , min_scale_(std::move(rhs.min_scale_))
+    , max_scale_(std::move(rhs.max_scale_))
+    , syms_(std::move(rhs.syms_))
+    , filter_(std::move(rhs.filter_))
+    , else_filter_(std::move(rhs.else_filter_))
+    , also_filter_(std::move(rhs.also_filter_))
+{}
 
 rule& rule::operator=(rule rhs)
 {
@@ -84,19 +85,14 @@ rule& rule::operator=(rule rhs)
 
 bool rule::operator==(rule const& rhs) const
 {
-    return  (name_ == rhs.name_) &&
-        (min_scale_ == rhs.min_scale_) &&
-        (max_scale_ == rhs.max_scale_) &&
-        (syms_ == rhs.syms_) &&
-        (filter_ == rhs.filter_) &&
-        (else_filter_ == rhs.else_filter_) &&
-        (also_filter_ == rhs.also_filter_);
+    return (name_ == rhs.name_) && (min_scale_ == rhs.min_scale_) && (max_scale_ == rhs.max_scale_) &&
+           (syms_ == rhs.syms_) && (filter_ == rhs.filter_) && (else_filter_ == rhs.else_filter_) &&
+           (also_filter_ == rhs.also_filter_);
 }
 
-
 void rule::set_max_scale(double scale)
 {
-    max_scale_=scale;
+    max_scale_ = scale;
 }
 
 double rule::get_max_scale() const
@@ -106,7 +102,7 @@ double rule::get_max_scale() const
 
 void rule::set_min_scale(double scale)
 {
-    min_scale_=scale;
+    min_scale_ = scale;
 }
 
 double rule::get_min_scale() const
@@ -116,7 +112,7 @@ double rule::get_min_scale() const
 
 void rule::set_name(std::string const& name)
 {
-    name_=name;
+    name_ = name;
 }
 
 std::string const& rule::get_name() const
@@ -124,7 +120,7 @@ std::string const& rule::get_name() const
     return name_;
 }
 
-void rule::append(symbolizer && sym)
+void rule::append(symbolizer&& sym)
 {
     syms_.push_back(std::move(sym));
 }
@@ -133,7 +129,7 @@ void rule::remove_at(size_t index)
 {
     if (index < syms_.size())
     {
-        syms_.erase(syms_.begin()+index);
+        syms_.erase(syms_.begin() + index);
     }
 }
 
@@ -164,7 +160,7 @@ rule::symbolizers::iterator rule::end()
 
 void rule::set_filter(expression_ptr const& filter)
 {
-    filter_=filter;
+    filter_ = filter;
 }
 
 expression_ptr const& rule::get_filter() const
@@ -174,7 +170,7 @@ expression_ptr const& rule::get_filter() const
 
 void rule::set_else(bool else_filter)
 {
-    else_filter_=else_filter;
+    else_filter_ = else_filter;
 }
 
 bool rule::has_else_filter() const
@@ -184,7 +180,7 @@ bool rule::has_else_filter() const
 
 void rule::set_also(bool also_filter)
 {
-    also_filter_=also_filter;
+    also_filter_ = also_filter;
 }
 
 bool rule::has_also_filter() const
@@ -192,4 +188,4 @@ bool rule::has_also_filter() const
     return also_filter_;
 }
 
-}
+} // namespace mapnik
