@@ -23,18 +23,24 @@
 // mapnik
 #include <mapnik/scale_denominator.hpp>
 #include <mapnik/global.hpp>
+#include <mapnik/well_known_srs.hpp>
 
 // stl
 #include <cmath>
 
 namespace mapnik {
 
-static const double meters_per_degree = 6378137 * 2 * M_PI / 360;
+static const double meters_per_degree = EARTH_CIRCUMFERENCE / 360;
 
 double scale_denominator(double map_scale, bool geographic)
 {
-    double denom = map_scale / 0.00028;
-    if (geographic) denom *= meters_per_degree;
+    // Pixel size in meters.
+    // Corresponding approximate resolution is 90.71 DPI.
+    constexpr double pixel_size = 0.00028;
+
+    double denom = map_scale / pixel_size;
+    if (geographic)
+        denom *= meters_per_degree;
     return denom;
 }
-}
+} // namespace mapnik
