@@ -28,18 +28,18 @@
 #include <cstdlib>
 #include <stdexcept>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
 
 // freetype2
-extern "C"
-{
+extern "C" {
 #include <ft2build.h>
 #include FT_FREETYPE_H
 #include FT_MODULE_H
 }
 
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 namespace {
 
@@ -48,7 +48,7 @@ void* _Alloc_Func(FT_Memory, long size)
     return std::malloc(mapnik::safe_cast<std::size_t>(size));
 }
 
-void _Free_Func(FT_Memory, void *block)
+void _Free_Func(FT_Memory, void* block)
 {
     std::free(block);
 }
@@ -58,19 +58,20 @@ void* _Realloc_Func(FT_Memory, long /*cur_size*/, long new_size, void* block)
     return std::realloc(block, mapnik::safe_cast<std::size_t>(new_size));
 }
 
-}
+} // namespace
 
 namespace mapnik {
 
 font_library::font_library()
-  : library_(nullptr),
-    memory_(new FT_MemoryRec_)
+    : library_(nullptr)
+    , memory_(new FT_MemoryRec_)
 {
     memory_->alloc = _Alloc_Func;
     memory_->free = _Free_Func;
     memory_->realloc = _Realloc_Func;
     FT_Error error = FT_New_Library(&*memory_, &library_);
-    if (error) throw std::runtime_error("can not initialize FreeType2 library");
+    if (error)
+        throw std::runtime_error("can not initialize FreeType2 library");
     FT_Add_Default_Modules(library_);
 }
 
