@@ -30,21 +30,20 @@
 #include <mapnik/text/text_layout.hpp>
 #include <mapnik/debug.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
 #include <boost/property_tree/ptree.hpp>
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
-namespace mapnik
-{
-namespace formatting
-{
+namespace mapnik {
+namespace formatting {
 
 using boost::property_tree::ptree;
 
-void text_node::to_xml(ptree & xml) const
+void text_node::to_xml(ptree& xml) const
 {
-    ptree & new_node = xml.push_back(ptree::value_type("<xmltext>", ptree()))->second;
+    ptree& new_node = xml.push_back(ptree::value_type("<xmltext>", ptree()))->second;
     new_node.put_value(to_expression_string(*text_));
 }
 
@@ -53,53 +52,57 @@ node_ptr text_node::from_xml(xml_node const& xml, fontset_map const&)
     return std::make_shared<text_node>(xml.get_value<expression_ptr>());
 }
 
-void text_node::apply(evaluated_format_properties_ptr const& p, feature_impl const& feature, attributes const& vars, text_layout &output) const
+void text_node::apply(evaluated_format_properties_ptr const& p,
+                      feature_impl const& feature,
+                      attributes const& vars,
+                      text_layout& output) const
 {
-    mapnik::value_unicode_string text_str = util::apply_visitor(evaluate<feature_impl,value_type,attributes>(feature,vars), *text_).to_unicode();
+    mapnik::value_unicode_string text_str =
+      util::apply_visitor(evaluate<feature_impl, value_type, attributes>(feature, vars), *text_).to_unicode();
     switch (p->text_transform)
     {
-    case UPPERCASE:
-        text_str.toUpper();
-        break;
-    case LOWERCASE:
-        text_str.toLower();
-        break;
-    case REVERSE:
-        text_str.reverse();
-        break;
-    case CAPITALIZE:
+        case text_transform_enum::UPPERCASE:
+            text_str.toUpper();
+            break;
+        case text_transform_enum::LOWERCASE:
+            text_str.toLower();
+            break;
+        case text_transform_enum::REVERSE:
+            text_str.reverse();
+            break;
+        case text_transform_enum::CAPITALIZE:
 #if !UCONFIG_NO_BREAK_ITERATION
-        // note: requires BreakIterator support in ICU which is optional
-        text_str.toTitle(nullptr);
+            // note: requires BreakIterator support in ICU which is optional
+            text_str.toTitle(nullptr);
 #else
-        MAPNIK_LOG_DEBUG(text_node) << "text capitalize (toTitle) disabled because ICU was built without UCONFIG_NO_BREAK_ITERATION";
+            MAPNIK_LOG_DEBUG(text_node)
+              << "text capitalize (toTitle) disabled because ICU was built without UCONFIG_NO_BREAK_ITERATION";
 #endif
-        break;
-    default:
-        break;
+            break;
+        default:
+            break;
     }
-    if (text_str.length() > 0) {
+    if (text_str.length() > 0)
+    {
         output.add_text(text_str, p);
     }
 }
 
-
-void text_node::add_expressions(expression_set &output) const
+void text_node::add_expressions(expression_set& output) const
 {
-    if (text_) output.insert(text_);
+    if (text_)
+        output.insert(text_);
 }
 
-
 void text_node::set_text(expression_ptr text)
 {
     text_ = text;
 }
 
-
 expression_ptr text_node::get_text() const
 {
     return text_;
 }
 
-} //ns formatting
-} //ns mapnik
+} // namespace formatting
+} // namespace mapnik
