@@ -27,31 +27,33 @@
 #include <mapnik/feature.hpp>
 #include <mapnik/symbolizer.hpp>
 #include <mapnik/text/harfbuzz_shaper.hpp>
-#include <mapnik/make_unique.hpp>
+#include <mapnik/util/math.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
 #include <unicode/brkiter.h>
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 #include <algorithm>
+#include <memory>
 
-namespace mapnik
-{
+namespace mapnik {
 
 // Output is centered around (0,0)
-static void rotated_box2d(box2d<double> & box, rotation const& rot, pixel_position const& center, double width, double height)
+static void
+  rotated_box2d(box2d<double>& box, rotation const& rot, pixel_position const& center, double width, double height)
 {
     double half_width, half_height;
     if (rot.sin == 0 && rot.cos == 1.)
     {
-        half_width  = width / 2.;
+        half_width = width / 2.;
         half_height = height / 2.;
     }
     else
     {
-        half_width  = (width * rot.cos + height * rot.sin) /2.;
-        half_height = (width * rot.sin + height * rot.cos) /2.;
+        half_width = (width * rot.cos + height * rot.sin) / 2.;
+        half_height = (width * rot.sin + height * rot.cos) / 2.;
     }
     box.init(center.x - half_width, center.y - half_height, center.x + half_width, center.y + half_height);
 }
@@ -60,105 +62,105 @@ pixel_position evaluate_displacement(double dx, double dy, directions_e dir)
 {
     switch (dir)
     {
-    case EXACT_POSITION:
-        return pixel_position(dx,dy);
-        break;
-    case NORTH:
-        return pixel_position(0,-std::abs(dy));
-        break;
-    case EAST:
-        return pixel_position(std::abs(dx),0);
-        break;
-    case SOUTH:
-        return pixel_position(0,std::abs(dy));
-        break;
-    case WEST:
-        return pixel_position(-std::abs(dx),0);
-        break;
-    case NORTHEAST:
-        return pixel_position(std::abs(dx),-std::abs(dy));
-        break;
-    case SOUTHEAST:
-        return pixel_position(std::abs(dx),std::abs(dy));
-        break;
-    case NORTHWEST:
-        return pixel_position(-std::abs(dx),-std::abs(dy));
-        break;
-    case SOUTHWEST:
-        return pixel_position(-std::abs(dx),std::abs(dy));
-        break;
-    default:
-        return pixel_position(dx,dy);
+        case EXACT_POSITION:
+            return pixel_position(dx, dy);
+        case NORTH:
+            return pixel_position(0, -std::abs(dy));
+        case EAST:
+            return pixel_position(std::abs(dx), 0);
+        case SOUTH:
+            return pixel_position(0, std::abs(dy));
+        case WEST:
+            return pixel_position(-std::abs(dx), 0);
+        case NORTHEAST:
+            return pixel_position(std::abs(dx), -std::abs(dy));
+        case SOUTHEAST:
+            return pixel_position(std::abs(dx), std::abs(dy));
+        case NORTHWEST:
+            return pixel_position(-std::abs(dx), -std::abs(dy));
+        case SOUTHWEST:
+            return pixel_position(-std::abs(dx), std::abs(dy));
+        case CENTER:
+            return pixel_position(0, 0);
+        default:
+            return pixel_position(dx, dy);
     }
 }
 
-pixel_position pixel_position::rotate(rotation const& rot) const
-{
-    return pixel_position(x * rot.cos - y * rot.sin, x * rot.sin + y * rot.cos);
-}
-
-text_layout::text_layout(face_manager_freetype & font_manager,
+text_layout::text_layout(face_manager_freetype& font_manager,
                          feature_impl const& feature,
                          attributes const& attrs,
                          double scale_factor,
                          text_symbolizer_properties const& properties,
                          text_layout_properties const& layout_defaults,
                          formatting::node_ptr tree)
-    : font_manager_(font_manager),
-      scale_factor_(scale_factor),
-      itemizer_(),
-      width_map_(),
-      width_(0.0),
-      height_(0.0),
-      glyphs_count_(0),
-      lines_(),
-      layout_properties_(layout_defaults),
-      properties_(properties),
-      format_(std::make_unique<detail::evaluated_format_properties>())
-    {
-        double dx = util::apply_visitor(extract_value<value_double>(feature,attrs), layout_properties_.dx);
-        double dy = util::apply_visitor(extract_value<value_double>(feature,attrs), layout_properties_.dy);
-        displacement_ = evaluate_displacement(dx,dy, layout_properties_.dir);
-        std::string wrap_str = util::apply_visitor(extract_value<std::string>(feature,attrs), layout_properties_.wrap_char);
-        if (!wrap_str.empty()) wrap_char_ = wrap_str[0];
-        wrap_width_ = util::apply_visitor(extract_value<value_double>(feature,attrs), layout_properties_.wrap_width);
-        double angle = util::apply_visitor(extract_value<value_double>(feature,attrs), layout_properties_.orientation);
-        orientation_.init(angle * M_PI/ 180.0);
-        wrap_before_ = util::apply_visitor(extract_value<value_bool>(feature,attrs), layout_properties_.wrap_before);
-        repeat_wrap_char_ = util::apply_visitor(extract_value<value_bool>(feature,attrs), layout_properties_.repeat_wrap_char);
-        rotate_displacement_ = util::apply_visitor(extract_value<value_bool>(feature,attrs), layout_properties_.rotate_displacement);
-        valign_ = util::apply_visitor(extract_value<vertical_alignment_enum>(feature,attrs),layout_properties_.valign);
-        halign_ = util::apply_visitor(extract_value<horizontal_alignment_enum>(feature,attrs),layout_properties_.halign);
-        jalign_ = util::apply_visitor(extract_value<justify_alignment_enum>(feature,attrs),layout_properties_.jalign);
+    : font_manager_(font_manager)
+    , scale_factor_(scale_factor)
+    , itemizer_()
+    , width_map_()
+    , width_(0.0)
+    , height_(0.0)
+    , glyphs_count_(0)
+    , lines_()
+    , layout_properties_(layout_defaults)
+    , properties_(properties)
+    , format_(std::make_unique<detail::evaluated_format_properties>())
+{
+    double dx = util::apply_visitor(extract_value<value_double>(feature, attrs), layout_properties_.dx);
+    double dy = util::apply_visitor(extract_value<value_double>(feature, attrs), layout_properties_.dy);
+    displacement_ = evaluate_displacement(dx, dy, layout_properties_.dir);
+    std::string wrap_str =
+      util::apply_visitor(extract_value<std::string>(feature, attrs), layout_properties_.wrap_char);
+    if (!wrap_str.empty())
+        wrap_char_ = wrap_str[0];
+    wrap_width_ = util::apply_visitor(extract_value<value_double>(feature, attrs), layout_properties_.wrap_width);
+    double angle = util::apply_visitor(extract_value<value_double>(feature, attrs), layout_properties_.orientation);
+    orientation_.init(util::radians(angle));
+    wrap_before_ = util::apply_visitor(extract_value<value_bool>(feature, attrs), layout_properties_.wrap_before);
+    repeat_wrap_char_ =
+      util::apply_visitor(extract_value<value_bool>(feature, attrs), layout_properties_.repeat_wrap_char);
+    rotate_displacement_ =
+      util::apply_visitor(extract_value<value_bool>(feature, attrs), layout_properties_.rotate_displacement);
+    valign_ = util::apply_visitor(extract_value<vertical_alignment_enum>(feature, attrs), layout_properties_.valign);
+    halign_ = util::apply_visitor(extract_value<horizontal_alignment_enum>(feature, attrs), layout_properties_.halign);
+    jalign_ = util::apply_visitor(extract_value<justify_alignment_enum>(feature, attrs), layout_properties_.jalign);
 
-        // Takes a feature and produces formatted text as output.
-        if (tree)
+    // Takes a feature and produces formatted text as output.
+    if (tree)
+    {
+        format_properties const& format_defaults = properties_.format_defaults;
+        format_->text_size =
+          util::apply_visitor(extract_value<value_double>(feature, attrs), format_defaults.text_size);
+        format_->character_spacing =
+          util::apply_visitor(extract_value<value_double>(feature, attrs), format_defaults.character_spacing);
+        format_->line_spacing =
+          util::apply_visitor(extract_value<value_double>(feature, attrs), format_defaults.line_spacing);
+        format_->text_opacity =
+          util::apply_visitor(extract_value<value_double>(feature, attrs), format_defaults.text_opacity);
+        format_->halo_opacity =
+          util::apply_visitor(extract_value<value_double>(feature, attrs), format_defaults.halo_opacity);
+        format_->halo_radius =
+          util::apply_visitor(extract_value<value_double>(feature, attrs), format_defaults.halo_radius);
+        format_->fill = util::apply_visitor(extract_value<color>(feature, attrs), format_defaults.fill);
+        format_->halo_fill = util::apply_visitor(extract_value<color>(feature, attrs), format_defaults.halo_fill);
+        format_->text_transform =
+          util::apply_visitor(extract_value<text_transform_enum>(feature, attrs), format_defaults.text_transform);
+        format_->face_name = format_defaults.face_name;
+        format_->fontset = format_defaults.fontset;
+        format_->ff_settings =
+          util::apply_visitor(extract_value<font_feature_settings>(feature, attrs), format_defaults.ff_settings);
+        // Turn off ligatures if character_spacing > 0.
+        if (format_->character_spacing > .0 && format_->ff_settings.count() == 0)
         {
-            format_properties const& format_defaults = properties_.format_defaults;
-            format_->text_size = util::apply_visitor(extract_value<value_double>(feature,attrs), format_defaults.text_size);
-            format_->character_spacing = util::apply_visitor(extract_value<value_double>(feature,attrs), format_defaults.character_spacing);
-            format_->line_spacing = util::apply_visitor(extract_value<value_double>(feature,attrs), format_defaults.line_spacing);
-            format_->text_opacity = util::apply_visitor(extract_value<value_double>(feature,attrs), format_defaults.text_opacity);
-            format_->halo_opacity = util::apply_visitor(extract_value<value_double>(feature,attrs), format_defaults.halo_opacity);
-            format_->halo_radius = util::apply_visitor(extract_value<value_double>(feature,attrs), format_defaults.halo_radius);
-            format_->fill = util::apply_visitor(extract_value<color>(feature,attrs), format_defaults.fill);
-            format_->halo_fill = util::apply_visitor(extract_value<color>(feature,attrs), format_defaults.halo_fill);
-            format_->text_transform = util::apply_visitor(extract_value<text_transform_enum>(feature,attrs), format_defaults.text_transform);
-            format_->face_name = format_defaults.face_name;
-            format_->fontset = format_defaults.fontset;
-            format_->ff_settings = util::apply_visitor(extract_value<font_feature_settings>(feature,attrs), format_defaults.ff_settings);
-            // Turn off ligatures if character_spacing > 0.
-            if (format_->character_spacing > .0 && format_->ff_settings.count() == 0)
-            {
-                format_->ff_settings.append(font_feature_liga_off);
-            }
-            tree->apply(format_, feature, attrs, *this);
-        }
-        else
-        {
-            MAPNIK_LOG_WARN(text_properties) << "text_symbolizer_properties can't produce text: No formatting tree!";
+            format_->ff_settings.append(font_feature_liga_off);
         }
+        tree->apply(format_, feature, attrs, *this);
     }
+    else
+    {
+        MAPNIK_LOG_WARN(text_properties) << "text_symbolizer_properties can't produce text: No formatting tree!";
+    }
+}
 
 void text_layout::add_text(mapnik::value_unicode_string const& str, evaluated_format_properties_ptr const& format)
 {
@@ -170,13 +172,12 @@ void text_layout::add_child(text_layout_ptr const& child_layout)
     child_layout_list_.push_back(child_layout);
 }
 
-evaluated_format_properties_ptr & text_layout::new_child_format_ptr(evaluated_format_properties_ptr const& p)
+evaluated_format_properties_ptr& text_layout::new_child_format_ptr(evaluated_format_properties_ptr const& p)
 {
     format_ptrs_.emplace_back(std::make_unique<detail::evaluated_format_properties>(*p));
     return format_ptrs_.back();
 }
 
-
 mapnik::value_unicode_string const& text_layout::text() const
 {
     return itemizer_.text();
@@ -202,7 +203,8 @@ void text_layout::layout()
 
     // Find text origin.
     displacement_ = scale_factor_ * displacement_ + alignment_offset();
-    if (rotate_displacement_) displacement_ = displacement_.rotate(!orientation_);
+    if (rotate_displacement_)
+        displacement_ = displacement_.rotate(!orientation_);
     // Find layout bounds, expanded for rotation
     rotated_box2d(bounds_, orientation_, displacement_, width_, height_);
 }
@@ -211,7 +213,7 @@ void text_layout::layout()
 // This makes line breaking easy. One word is added to the current line at a time. Once the line is too long
 // we either go back one step or insert the line break at the current position (depending on "wrap_before" setting).
 // At the end everything that is left over is added as the final line.
-void text_layout::break_line_icu(std::pair<unsigned, unsigned> && line_limits)
+void text_layout::break_line_icu(std::pair<unsigned, unsigned>&& line_limits)
 {
     using BreakIterator = icu::BreakIterator;
     text_line line(line_limits.first, line_limits.second);
@@ -228,9 +230,10 @@ void text_layout::break_line_icu(std::pair<unsigned, unsigned> && line_limits)
         double wrap_at;
         double string_width = line.width();
         double string_height = line.line_height();
-        for (double i = 1.0;
-             ((wrap_at = string_width/i)/(string_height*i)) > text_ratio_ && (string_width/i) > scaled_wrap_width;
-             i += 1.0) ;
+        for (double i = 1.0; ((wrap_at = string_width / i) / (string_height * i)) > text_ratio_ &&
+                             (string_width / i) > scaled_wrap_width;
+             i += 1.0)
+            ;
         scaled_wrap_width = wrap_at;
     }
 
@@ -259,7 +262,8 @@ void text_layout::break_line_icu(std::pair<unsigned, unsigned> && line_limits)
         {
             current_line_length += width_itr->second;
         }
-        if (current_line_length <= scaled_wrap_width) continue;
+        if (current_line_length <= scaled_wrap_width)
+            continue;
 
         int break_position = wrap_before_ ? breakitr->preceding(i + 1) : breakitr->following(i);
         // following() returns a break position after the last word. So DONE should only be returned
@@ -313,21 +317,24 @@ void text_layout::break_line_icu(std::pair<unsigned, unsigned> && line_limits)
 
 struct line_breaker : util::noncopyable
 {
-    line_breaker(value_unicode_string const& ustr, char  wrap_char)
-        : ustr_(ustr),
-          wrap_char_(wrap_char) {}
+    line_breaker(value_unicode_string const& ustr, char wrap_char)
+        : ustr_(ustr)
+        , wrap_char_(wrap_char)
+    {}
 
     std::int32_t following(std::int32_t offset)
     {
         std::int32_t pos = ustr_.indexOf(wrap_char_, offset);
-        if (pos != -1) ++pos;
+        if (pos != -1)
+            ++pos;
         return pos;
     }
 
     std::int32_t preceding(std::int32_t offset)
     {
         std::int32_t pos = ustr_.lastIndexOf(wrap_char_, 0, offset);
-        if (pos != -1) ++pos;
+        if (pos != -1)
+            ++pos;
         return pos;
     }
 
@@ -335,13 +342,15 @@ struct line_breaker : util::noncopyable
     char wrap_char_;
 };
 
-inline int adjust_last_break_position (int pos, bool repeat_wrap_char)
+inline int adjust_last_break_position(int pos, bool repeat_wrap_char)
 {
-    if (repeat_wrap_char)  return (pos==0) ? 0: pos - 1;
-    else return pos;
+    if (repeat_wrap_char)
+        return (pos == 0) ? 0 : pos - 1;
+    else
+        return pos;
 }
 
-void text_layout::break_line(std::pair<unsigned, unsigned> && line_limits)
+void text_layout::break_line(std::pair<unsigned, unsigned>&& line_limits)
 {
     using BreakIterator = icu::BreakIterator;
     text_line line(line_limits.first, line_limits.second);
@@ -351,28 +360,31 @@ void text_layout::break_line(std::pair<unsigned, unsigned> && line_limits)
     {
         add_line(std::move(line));
         return;
-
     }
     if (text_ratio_)
     {
         double wrap_at;
         double string_width = line.width();
         double string_height = line.line_height();
-        for (double i = 1.0; ((wrap_at = string_width/i)/(string_height*i)) > text_ratio_ && (string_width/i) > scaled_wrap_width; i += 1.0) ;
+        for (double i = 1.0; ((wrap_at = string_width / i) / (string_height * i)) > text_ratio_ &&
+                             (string_width / i) > scaled_wrap_width;
+             i += 1.0)
+            ;
         scaled_wrap_width = wrap_at;
     }
     mapnik::value_unicode_string const& text = itemizer_.text();
     line_breaker breaker(text, wrap_char_);
     double current_line_length = 0;
     int last_break_position = static_cast<int>(line.first_char());
-    for (unsigned i=line.first_char(); i < line.last_char(); ++i)
+    for (unsigned i = line.first_char(); i < line.last_char(); ++i)
     {
         std::map<unsigned, double>::const_iterator width_itr = width_map_.find(i);
         if (width_itr != width_map_.end())
         {
             current_line_length += width_itr->second;
         }
-        if (current_line_length <= scaled_wrap_width) continue;
+        if (current_line_length <= scaled_wrap_width)
+            continue;
 
         int break_position = wrap_before_ ? breaker.preceding(i + 1) : breaker.following(i);
         if (break_position <= last_break_position || break_position == static_cast<int>(BreakIterator::DONE))
@@ -412,7 +424,7 @@ void text_layout::break_line(std::pair<unsigned, unsigned> && line_limits)
     }
 }
 
-void text_layout::add_line(text_line && line)
+void text_layout::add_line(text_line&& line)
 {
     if (lines_.empty())
     {
@@ -426,7 +438,7 @@ void text_layout::add_line(text_line && line)
 
 void text_layout::clear_cluster_widths(unsigned first, unsigned last)
 {
-    for (unsigned i=first; i<last; ++i)
+    for (unsigned i = first; i < last; ++i)
     {
         width_map_[i] = 0;
     }
@@ -442,72 +454,82 @@ void text_layout::clear()
     child_layout_list_.clear();
 }
 
-void text_layout::shape_text(text_line & line)
+void text_layout::shape_text(text_line& line)
 {
     harfbuzz_shaper::shape_text(line, itemizer_, width_map_, font_manager_, scale_factor_);
 }
 
 void text_layout::init_auto_alignment()
 {
-    if (valign_ == V_AUTO)
+    if (valign_ == vertical_alignment_enum::V_AUTO)
     {
-        if (displacement_.y > 0.0) valign_ = V_BOTTOM;
-        else if (displacement_.y < 0.0) valign_ = V_TOP;
-        else valign_ = V_MIDDLE;
+        if (displacement_.y > 0.0)
+            valign_ = vertical_alignment_enum::V_BOTTOM;
+        else if (displacement_.y < 0.0)
+            valign_ = vertical_alignment_enum::V_TOP;
+        else
+            valign_ = vertical_alignment_enum::V_MIDDLE;
     }
-    if (halign_ == H_AUTO)
+    if (halign_ == horizontal_alignment_enum::H_AUTO)
     {
-        if (displacement_.x > 0.0) halign_ = H_RIGHT;
-        else if (displacement_.x < 0.0) halign_ = H_LEFT;
-        else halign_ = H_MIDDLE;
+        if (displacement_.x > 0.0)
+            halign_ = horizontal_alignment_enum::H_RIGHT;
+        else if (displacement_.x < 0.0)
+            halign_ = horizontal_alignment_enum::H_LEFT;
+        else
+            halign_ = horizontal_alignment_enum::H_MIDDLE;
     }
-    if (jalign_ == J_AUTO)
+    if (jalign_ == justify_alignment_enum::J_AUTO)
     {
-        if (displacement_.x > 0.0) jalign_ = J_LEFT;
-        else if (displacement_.x < 0.0) jalign_ = J_RIGHT;
-        else jalign_ = J_MIDDLE;
+        if (displacement_.x > 0.0)
+            jalign_ = justify_alignment_enum::J_LEFT;
+        else if (displacement_.x < 0.0)
+            jalign_ = justify_alignment_enum::J_RIGHT;
+        else
+            jalign_ = justify_alignment_enum::J_MIDDLE;
     }
 }
 
 pixel_position text_layout::alignment_offset() const
 {
-    pixel_position result(0,0);
+    pixel_position result(0, 0);
     // if needed, adjust for desired vertical alignment
-    if (valign_ == V_TOP)
+    if (valign_ == vertical_alignment_enum::V_TOP)
     {
-        result.y = -0.5 * height();  // move center up by 1/2 the total height
+        result.y = -0.5 * height(); // move center up by 1/2 the total height
     }
-    else if (valign_ == V_BOTTOM)
+    else if (valign_ == vertical_alignment_enum::V_BOTTOM)
     {
-        result.y = 0.5 * height();  // move center down by the 1/2 the total height
+        result.y = 0.5 * height(); // move center down by the 1/2 the total height
     }
     // set horizontal position to middle of text
-    if (halign_ == H_LEFT)
+    if (halign_ == horizontal_alignment_enum::H_LEFT)
     {
-        result.x = -0.5 * width();  // move center left by 1/2 the string width
+        result.x = -0.5 * width(); // move center left by 1/2 the string width
     }
-    else if (halign_ == H_RIGHT)
+    else if (halign_ == horizontal_alignment_enum::H_RIGHT)
     {
-        result.x = 0.5 * width();  // move center right by 1/2 the string width
+        result.x = 0.5 * width(); // move center right by 1/2 the string width
     }
     return result;
 }
 
 double text_layout::jalign_offset(double line_width) const
 {
-    if (jalign_ == J_MIDDLE) return -(line_width / 2.0);
-    if (jalign_ == J_LEFT)   return -(width() / 2.0);
-    if (jalign_ == J_RIGHT)  return (width() / 2.0) - line_width;
+    if (jalign_ == justify_alignment_enum::J_MIDDLE)
+        return -(line_width / 2.0);
+    if (jalign_ == justify_alignment_enum::J_LEFT)
+        return -(width() / 2.0);
+    if (jalign_ == justify_alignment_enum::J_RIGHT)
+        return (width() / 2.0) - line_width;
     return 0;
 }
 
 text_layout::const_iterator text_layout::longest_line() const
 {
-    return std::max_element(lines_.begin(), lines_.end(),
-        [](text_line const& line1, text_line const& line2)
-        {
-            return line1.glyphs_width() < line2.glyphs_width();
-        });
+    return std::max_element(lines_.begin(), lines_.end(), [](text_line const& line1, text_line const& line2) {
+        return line1.glyphs_width() < line2.glyphs_width();
+    });
 }
 
 void layout_container::add(text_layout_ptr layout)
@@ -523,7 +545,7 @@ void layout_container::add(text_layout_ptr layout)
 
 void layout_container::layout()
 {
-    bounds_.init(0,0,0,0);
+    bounds_.init(0, 0, 0, 0);
     glyphs_count_ = 0;
     line_count_ = 0;
 
@@ -551,10 +573,9 @@ void layout_container::clear()
 {
     layouts_.clear();
     text_.remove();
-    bounds_.init(0,0,0,0);
+    bounds_.init(0, 0, 0, 0);
     glyphs_count_ = 0;
     line_count_ = 0;
 }
 
-
-} //ns mapnik
+} // namespace mapnik
