@@ -21,41 +21,36 @@
  *****************************************************************************/
 
 // mapnik
-#include <mapnik/make_unique.hpp>
 #include <mapnik/debug.hpp>
 #include <mapnik/image_reader.hpp>
 
-#pragma GCC diagnostic push
+#include <mapnik/warning.hpp>
+MAPNIK_DISABLE_WARNING_PUSH
 #include <mapnik/warning_ignore.hpp>
-extern "C"
-{
+extern "C" {
 #include <webp/types.h>
 #include <webp/decode.h>
 }
 
-#pragma GCC diagnostic pop
+MAPNIK_DISABLE_WARNING_POP
 
 // stl
 #include <fstream>
+#include <memory>
+#include <algorithm>
 
-namespace mapnik
-{
+namespace mapnik {
 
 struct external_buffer_policy
 {
-    external_buffer_policy( uint8_t const* data, std::size_t size)
-        : data_(data),
-          size_(size) {}
+    external_buffer_policy(uint8_t const* data, std::size_t size)
+        : data_(data)
+        , size_(size)
+    {}
 
-    uint8_t const* data() const
-    {
-        return data_;
-    }
+    uint8_t const* data() const { return data_; }
 
-    std::size_t size() const
-    {
-        return size_;
-    }
+    std::size_t size() const { return size_; }
 
     uint8_t const* data_;
     std::size_t size_;
@@ -64,44 +59,34 @@ struct external_buffer_policy
 struct internal_buffer_policy
 {
     internal_buffer_policy(std::size_t size)
-        : data_((size!=0) ? static_cast<uint8_t*>(::operator new(sizeof(uint8_t) * size)) : 0),
-          size_(size)
+        : data_((size != 0) ? static_cast<uint8_t*>(::operator new(sizeof(uint8_t) * size)) : 0)
+        , size_(size)
     {}
 
-    uint8_t * data() const
-    {
-        return data_;
-    }
+    uint8_t* data() const { return data_; }
 
-    std::size_t size() const
-    {
-        return size_;
-    }
+    std::size_t size() const { return size_; }
 
-    ~internal_buffer_policy()
-    {
-        ::operator delete(data_), data_=0;
-    }
+    ~internal_buffer_policy() { ::operator delete(data_), data_ = 0; }
 
-    uint8_t * data_;
+    uint8_t* data_;
     std::size_t size_;
 };
 
-template <typename T>
+template<typename T>
 class webp_reader : public image_reader
 {
     using buffer_policy_type = T;
-private:
+
+  private:
     struct config_guard
     {
-        config_guard(WebPDecoderConfig & config)
-            : config_(config) {}
+        config_guard(WebPDecoderConfig& config)
+            : config_(config)
+        {}
 
-        ~config_guard()
-        {
-            WebPFreeDecBuffer(&config_.output);
-        }
-        WebPDecoderConfig & config_;
+        ~config_guard() { WebPFreeDecBuffer(&config_.output); }
+        WebPDecoderConfig& config_;
     };
 
     std::unique_ptr<buffer_policy_type> buffer_;
@@ -109,23 +94,23 @@ private:
     unsigned width_;
     unsigned height_;
     bool has_alpha_;
-public:
+
+  public:
     explicit webp_reader(char const* data, std::size_t size);
     explicit webp_reader(std::string const& filename);
     ~webp_reader();
     unsigned width() const final;
     unsigned height() const final;
-    boost::optional<box2d<double> > bounding_box() const final;
+    std::optional<box2d<double>> bounding_box() const final override;
     inline bool has_alpha() const final { return has_alpha_; }
-    void read(unsigned x,unsigned y,image_rgba8& image) final;
+    void read(unsigned x, unsigned y, image_rgba8& image) final;
     image_any read(unsigned x, unsigned y, unsigned width, unsigned height) final;
-private:
+
+  private:
     void init();
 };
 
-namespace
-{
-image_reader* create_webp_reader(char const * data, std::size_t size)
+image_reader* create_webp_reader(char const* data, std::size_t size)
 {
     return new webp_reader<external_buffer_policy>(data, size);
 }
@@ -135,30 +120,30 @@ image_reader* create_webp_reader2(std::string const& filename)
     return new webp_reader<internal_buffer_policy>(filename);
 }
 
-
-const bool registered = register_image_reader("webp", create_webp_reader);
-const bool registered2 = register_image_reader("webp", create_webp_reader2);
-
+void register_webp_reader()
+{
+    const bool registered = register_image_reader("webp", create_webp_reader);
+    const bool registered2 = register_image_reader("webp", create_webp_reader2);
 }
 
 // ctor
-template <typename T>
+template<typename T>
 webp_reader<T>::webp_reader(char const* data, std::size_t size)
-    : buffer_(new buffer_policy_type(reinterpret_cast<uint8_t const*>(data), size)),
-      width_(0),
-      height_(0),
-      has_alpha_(false)
+    : buffer_(new buffer_policy_type(reinterpret_cast<uint8_t const*>(data), size))
+    , width_(0)
+    , height_(0)
+    , has_alpha_(false)
 {
     init();
 }
 
-template <typename T>
+template<typename T>
 webp_reader<T>::webp_reader(std::string const& filename)
-    : buffer_(nullptr),
-      size_(0),
-      width_(0),
-      height_(0),
-      has_alpha_(false)
+    : buffer_(nullptr)
+    , size_(0)
+    , width_(0)
+    , height_(0)
+    , has_alpha_(false)
 {
     std::ifstream file(filename.c_str(), std::ios::binary);
     if (!file)
@@ -166,10 +151,10 @@ webp_reader<T>::webp_reader(std::string const& filename)
         throw image_reader_exception("WEBP: Can't read file:" + filename);
     }
     std::streampos beg = file.tellg();
-    file.seekg (0, std::ios::end);
+    file.seekg(0, std::ios::end);
     std::streampos end = file.tellg();
     std::size_t file_size = end - beg;
-    file.seekg (0, std::ios::beg);
+    file.seekg(0, std::ios::beg);
 
     auto buffer = std::make_unique<buffer_policy_type>(file_size);
     file.read(reinterpret_cast<char*>(buffer->data()), buffer->size());
@@ -182,15 +167,14 @@ webp_reader<T>::webp_reader(std::string const& filename)
     init();
 }
 
-
 // dtor
-template <typename T>
+template<typename T>
 webp_reader<T>::~webp_reader()
 {
     //
 }
 
-template <typename T>
+template<typename T>
 void webp_reader<T>::init()
 {
     WebPDecoderConfig config;
@@ -199,7 +183,8 @@ void webp_reader<T>::init()
     {
         throw image_reader_exception("WEBP reader: WebPInitDecoderConfig failed");
     }
-    if (WebPGetFeatures(buffer_->data(), buffer_->size(), &config.input) == VP8_STATUS_OK) {
+    if (WebPGetFeatures(buffer_->data(), buffer_->size(), &config.input) == VP8_STATUS_OK)
+    {
         width_ = config.input.width;
         height_ = config.input.height;
         has_alpha_ = config.input.has_alpha;
@@ -210,26 +195,26 @@ void webp_reader<T>::init()
     }
 }
 
-template <typename T>
+template<typename T>
 unsigned webp_reader<T>::width() const
 {
     return width_;
 }
 
-template <typename T>
+template<typename T>
 unsigned webp_reader<T>::height() const
 {
     return height_;
 }
 
-template <typename T>
-boost::optional<box2d<double> > webp_reader<T>::bounding_box() const
+template<typename T>
+std::optional<box2d<double>> webp_reader<T>::bounding_box() const
 {
-    return boost::optional<box2d<double> >();
+    return std::nullopt;
 }
 
-template <typename T>
-void webp_reader<T>::read(unsigned x0, unsigned y0,image_rgba8& image)
+template<typename T>
+void webp_reader<T>::read(unsigned x0, unsigned y0, image_rgba8& image)
 {
     WebPDecoderConfig config;
     config_guard guard(config);
@@ -250,7 +235,7 @@ void webp_reader<T>::read(unsigned x0, unsigned y0,image_rgba8& image)
     }
 
     config.output.colorspace = MODE_RGBA;
-    config.output.u.RGBA.rgba = reinterpret_cast<uint8_t *>(image.bytes());
+    config.output.u.RGBA.rgba = reinterpret_cast<uint8_t*>(image.bytes());
     config.output.u.RGBA.stride = 4 * image.width();
     config.output.u.RGBA.size = image.width() * image.height() * 4;
     config.output.is_external_memory = 1;
@@ -260,12 +245,12 @@ void webp_reader<T>::read(unsigned x0, unsigned y0,image_rgba8& image)
     }
 }
 
-template <typename T>
+template<typename T>
 image_any webp_reader<T>::read(unsigned x, unsigned y, unsigned width, unsigned height)
 {
-    image_rgba8 data(width,height);
+    image_rgba8 data(width, height);
     read(x, y, data);
     return image_any(std::move(data));
 }
 
-}
+} // namespace mapnik
