@@ -19,16 +19,16 @@
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  *
  *****************************************************************************/
-
-
+#include <string>
 #include <mapnik/geometry/boost_spirit_karma_adapter.hpp>
 #include <mapnik/wkt/wkt_generator_grammar_impl.hpp>
-#include <string>
 
-namespace mapnik { namespace wkt {
+namespace mapnik {
+namespace wkt {
 
 using sink_type = std::back_insert_iterator<std::string>;
 template struct wkt_generator_grammar<sink_type, mapnik::geometry::geometry<double>>;
 template struct wkt_generator_grammar<sink_type, mapnik::geometry::geometry<std::int64_t>>;
 
-}}
+} // namespace wkt
+} // namespace mapnik
