@@ -20,9 +20,8 @@
  *
  *****************************************************************************/
 
-//mapnik
+// mapnik
 #include <mapnik/debug.hpp>
-#include <mapnik/make_unique.hpp>
 #include <mapnik/xml_tree.hpp>
 #include <mapnik/xml_attribute_cast.hpp>
 #include <mapnik/util/conversions.hpp>
@@ -38,71 +37,76 @@
 
 // stl
 #include <type_traits>
+#include <memory>
 
-namespace mapnik
-{
+namespace mapnik {
 
 class boolean_type;
-template <typename T>
+
+template<typename T>
 struct name_trait
 {
-    static std::string name()
-    {
-        return "<unknown>";
-    }
+    static std::string name() { return "<unknown>"; }
     // missing name_trait for type ...
     // if you get here you are probably using a new type
     // in the XML file. Just add a name trait for the new
     // type below.
-    static_assert( sizeof(T) == 0, "missing name_trait for the type");
+    static_assert(sizeof(T) == 0, "missing name_trait for the type");
 };
 
-#define DEFINE_NAME_TRAIT( type, type_name )                            \
-    template <>                                                         \
-    struct name_trait<type>                                             \
-    {                                                                   \
-        static std::string name() { return std::string("type ") + type_name; } \
+#define DEFINE_NAME_TRAIT(type, type_name)                                                                             \
+    template<>                                                                                                         \
+    struct name_trait<type>                                                                                            \
+    {                                                                                                                  \
+        static std::string name()                                                                                      \
+        {                                                                                                              \
+            return std::string("type ") + type_name;                                                                   \
+        }                                                                                                              \
     };
 
-
-DEFINE_NAME_TRAIT( double, "double")
-DEFINE_NAME_TRAIT( float, "float")
-DEFINE_NAME_TRAIT( unsigned, "unsigned")
-DEFINE_NAME_TRAIT( int, "int")
-DEFINE_NAME_TRAIT( bool, "bool")
-DEFINE_NAME_TRAIT( boolean_type, "boolean_type")
+DEFINE_NAME_TRAIT(double, "double")
+DEFINE_NAME_TRAIT(float, "float")
+DEFINE_NAME_TRAIT(unsigned, "unsigned")
+DEFINE_NAME_TRAIT(int, "int")
+DEFINE_NAME_TRAIT(bool, "bool")
+DEFINE_NAME_TRAIT(boolean_type, "boolean_type")
 #ifdef BIGINT
-DEFINE_NAME_TRAIT( mapnik::value_integer, "long long" )
+DEFINE_NAME_TRAIT(mapnik::value_integer, "long long")
 #endif
-DEFINE_NAME_TRAIT( std::string, "string" )
-DEFINE_NAME_TRAIT( color, "color" )
-DEFINE_NAME_TRAIT( expression_ptr, "expression_ptr" )
-DEFINE_NAME_TRAIT( font_feature_settings, "font-feature-settings" )
+DEFINE_NAME_TRAIT(std::string, "string")
+DEFINE_NAME_TRAIT(color, "color")
+DEFINE_NAME_TRAIT(expression_ptr, "expression_ptr")
+DEFINE_NAME_TRAIT(font_feature_settings, "font-feature-settings")
 
-template <typename ENUM, int MAX>
-struct name_trait< mapnik::enumeration<ENUM, MAX> >
+template<typename ENUM,
+         char const* (*F_TO_STRING)(ENUM),
+         ENUM (*F_FROM_STRING)(const char*),
+         std::map<ENUM, std::string> (*F_LOOKUP)()>
+struct name_trait<mapnik::enumeration<ENUM, F_TO_STRING, F_FROM_STRING, F_LOOKUP>>
 {
-    using Enum = enumeration<ENUM, MAX>;
-
+    using Enum = mapnik::enumeration<ENUM, F_TO_STRING, F_FROM_STRING, F_LOOKUP>;
     static std::string name()
     {
         std::string value_list("one of [");
-        for (unsigned i = 0; i < Enum::MAX; ++i)
+        const auto lookup{Enum::lookupMap()};
+        for (auto it = lookup.cbegin(); it != lookup.cend(); it++)
         {
-            value_list += Enum::get_string( i );
-            if ( i + 1 < Enum::MAX ) value_list += ", ";
+            value_list += it->second;
+            if (std::next(it) != lookup.cend())
+            {
+                value_list += ", ";
+            }
         }
-        value_list += "]";
-
+        value_list += ']';
         return value_list;
     }
 };
 
 xml_tree::xml_tree()
-    : node_(*this, "<root>"),
-      file_()
+    : node_(*this, "<root>")
+    , file_()
 {
-    node_.set_processed(true); //root node is always processed
+    node_.set_processed(true); // root node is always processed
 }
 
 void xml_tree::set_filename(std::string const& fn)
@@ -115,66 +119,69 @@ std::string const& xml_tree::filename() const
     return file_;
 }
 
-xml_node & xml_tree::root()
+xml_node& xml_tree::root()
 {
     return node_;
 }
 
-const xml_node & xml_tree::root() const
+const xml_node& xml_tree::root() const
 {
     return node_;
 }
 
-xml_attribute::xml_attribute(const char * value_)
-    : value(value_),
-      processed(false) {}
+xml_attribute::xml_attribute(const char* value_)
+    : value(value_)
+    , processed(false)
+{}
 
 node_not_found::node_not_found(std::string const& node_name)
-    : node_name_(node_name),
-      msg_() {}
+    : node_name_(node_name)
+    , msg_()
+{}
 
 const char* node_not_found::what() const noexcept
 {
-    msg_ = std::string("Node "+node_name_+ "not found");
+    msg_ = std::string("Node " + node_name_ + "not found");
     return msg_.c_str();
 }
 
 node_not_found::~node_not_found() {}
 
-
-attribute_not_found::attribute_not_found(std::string const& node_name,
-                                         std::string const& attribute_name)
-    : node_name_(node_name),
-      attribute_name_(attribute_name),
-      msg_() {}
+attribute_not_found::attribute_not_found(std::string const& node_name, std::string const& attribute_name)
+    : node_name_(node_name)
+    , attribute_name_(attribute_name)
+    , msg_()
+{}
 
 const char* attribute_not_found::what() const noexcept
 {
-    msg_ = std::string("Attribute '" + attribute_name_ +"' not found in node '"+node_name_+ "'");
+    msg_ = std::string("Attribute '" + attribute_name_ + "' not found in node '" + node_name_ + "'");
     return msg_.c_str();
 }
 
 attribute_not_found::~attribute_not_found() {}
 
 more_than_one_child::more_than_one_child(std::string const& node_name)
-    : node_name_(node_name),
-      msg_() {}
+    : node_name_(node_name)
+    , msg_()
+{}
 
 const char* more_than_one_child::what() const noexcept
 {
-    msg_ = std::string("More than one child node in node '" + node_name_ +"'");
+    msg_ = std::string("More than one child node in node '" + node_name_ + "'");
     return msg_.c_str();
 }
 
 more_than_one_child::~more_than_one_child() {}
 
-xml_node::xml_node(xml_tree &tree, std::string && name, unsigned line, bool is_text)
-    : tree_(tree),
-      name_(std::move(name)),
-      is_text_(is_text),
-      line_(line),
-      processed_(false),
-      ignore_(false) {}
+xml_node::xml_node(xml_tree& tree, std::string&& name, unsigned line, bool is_text)
+    : tree_(tree)
+    , name_(std::move(name))
+    , is_text_(is_text)
+    , line_(line)
+    , processed_(false)
+    , ignore_(false)
+{}
 
 std::string xml_node::xml_text = "<xmltext>";
 
@@ -223,15 +230,15 @@ bool xml_node::is(std::string const& name) const
     return false;
 }
 
-xml_node & xml_node::add_child(const char * name, unsigned line, bool is_text)
+xml_node& xml_node::add_child(const char* name, unsigned line, bool is_text)
 {
     children_.emplace_back(tree_, name, line, is_text);
     return children_.back();
 }
 
-void xml_node::add_attribute(const char * name, const char * value)
+void xml_node::add_attribute(const char* name, const char* value_)
 {
-    auto result = attributes_.emplace(name,xml_attribute(value));
+    auto result = attributes_.emplace(name, xml_attribute(value_));
     if (!result.second)
     {
         MAPNIK_LOG_ERROR(xml_tree) << "ignoring duplicate attribute '" << name << "'";
@@ -278,7 +285,7 @@ xml_node::const_iterator xml_node::end() const
     return children_.end();
 }
 
-xml_node & xml_node::get_child(std::string const& name)
+xml_node& xml_node::get_child(std::string const& name)
 {
     std::list<xml_node>::iterator itr = children_.begin();
     std::list<xml_node>::iterator end = children_.end();
@@ -296,7 +303,8 @@ xml_node & xml_node::get_child(std::string const& name)
 xml_node const& xml_node::get_child(std::string const& name) const
 {
     xml_node const* node = get_opt_child(name);
-    if (!node) throw node_not_found(name);
+    if (!node)
+        throw node_not_found(name);
     return *node;
 }
 
@@ -325,36 +333,40 @@ bool xml_node::has_attribute(std::string const& name) const
     return attributes_.count(name) == 1 ? true : false;
 }
 
-template <typename T>
-boost::optional<T> xml_node::get_opt_attr(std::string const& name) const
+template<typename T>
+std::optional<T> xml_node::get_opt_attr(std::string const& name) const
 {
-    if (attributes_.empty()) return boost::optional<T>();
+    if (attributes_.empty())
+        return std::nullopt;
     std::map<std::string, xml_attribute>::const_iterator itr = attributes_.find(name);
-    if (itr ==  attributes_.end()) return boost::optional<T>();
+    if (itr == attributes_.end())
+        return std::nullopt;
     itr->second.processed = true;
-    boost::optional<T> result = xml_attribute_cast<T>(tree_, std::string(itr->second.value));
+    std::optional<T> result = xml_attribute_cast<T>(tree_, std::string(itr->second.value));
     if (!result)
     {
-        throw config_error(std::string("Failed to parse attribute '") +
-                           name + "'. Expected " + name_trait<T>::name() +
-                           " but got '" + itr->second.value + "'", *this);
+        throw config_error(std::string("Failed to parse attribute '") + name + "'. Expected " + name_trait<T>::name() +
+                             " but got '" + itr->second.value + "'",
+                           *this);
     }
     return result;
 }
 
-template <typename T>
+template<typename T>
 T xml_node::get_attr(std::string const& name, T const& default_opt_value) const
 {
-    boost::optional<T> value = get_opt_attr<T>(name);
-    if (value) return *value;
+    auto val = get_opt_attr<T>(name);
+    if (val)
+        return *val;
     return default_opt_value;
 }
 
-template <typename T>
+template<typename T>
 T xml_node::get_attr(std::string const& name) const
 {
-    boost::optional<T> value = get_opt_attr<T>(name);
-    if (value) return *value;
+    const auto val = get_opt_attr<T>(name);
+    if (val)
+        return *val;
     throw attribute_not_found(name_, name);
 }
 
@@ -380,16 +392,15 @@ std::string const& xml_node::get_text() const
     throw more_than_one_child(name_);
 }
 
-
-template <typename T>
+template<typename T>
 T xml_node::get_value() const
 {
-    boost::optional<T> result = xml_attribute_cast<T>(tree_, get_text());
+    std::optional<T> result = xml_attribute_cast<T>(tree_, get_text());
     if (!result)
     {
-        throw config_error(std::string("Failed to parse value. Expected ")
-                           + name_trait<T>::name() +
-                           " but got '" + get_text() + "'", *this);
+        throw config_error(std::string("Failed to parse value. Expected ") + name_trait<T>::name() + " but got '" +
+                             get_text() + "'",
+                           *this);
     }
     return *result;
 }
@@ -402,13 +413,14 @@ unsigned xml_node::line() const
 std::string xml_node::line_to_string() const
 {
     std::string number;
-    util::to_string(number,line_);
+    util::to_string(number, line_);
     return number;
 }
 
-
-#define compile_get_opt_attr(T) template boost::optional<T> xml_node::get_opt_attr<T>(std::string const&) const
-#define compile_get_attr(T) template T xml_node::get_attr<T>(std::string const&) const; template T xml_node::get_attr<T>(std::string const&, T const&) const
+#define compile_get_opt_attr(T) template std::optional<T> xml_node::get_opt_attr<T>(std::string const&) const
+#define compile_get_attr(T)                                                                                            \
+    template T xml_node::get_attr<T>(std::string const&) const;                                                        \
+    template T xml_node::get_attr<T>(std::string const&, T const&) const
 #define compile_get_value(T) template T xml_node::get_value<T>() const
 
 compile_get_opt_attr(boolean_type);
@@ -448,4 +460,4 @@ compile_get_attr(double);
 compile_get_value(value_integer);
 compile_get_value(double);
 compile_get_value(expression_ptr);
-} //ns mapnik
+} // namespace mapnik
